<?php
/*
 This program is distributed under the terms of the GNU General Public License.
 See the README & COPYING files for more information.
 Copyright (C) 2004-2005  Kevin L. Papendick <kevinp@polarlava.com>
*/

	//--- Includes
	require_once(LIB_PATH . 'PbDb_class.php');

	class PbBase
	{
		//--- Class Variables
		var $dbObj;
		var $prefix;
		var $id;



		//-----------------------------------------------
		//--- CONSTRUCTOR
		//--- PURPOSE:
		//---   Create base blog class object
		//--- PARAMETERS: table prefix (optional)
		//--- RETURNS: nothing
		//-----------------------------------------------
		function PbBase($prefix = 'wl_')
		{

			//--- Set DB Table Prefix
			$this->setDbPrefix($prefix);

			//--- Instatiate DB Object
			$this->setDbObj();
			$this->dbObj->setSafeSqlLib(LIB_PATH . 'SafeSQL.class.php');
		}


		//-----------------------------------------------
		//-----------------------------------------------
		//--- SET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------

		//-----------------------------------------------
		//--- METHOD: setDbObj
		//--- PURPOSE: set database object
		//--- PARAMETERS: none
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setDbObj()
		{
			$this->dbObj = &new PbDb();
		}

		//-----------------------------------------------
		//--- METHOD: setDbPrefix
		//--- PURPOSE: set database prefix
		//--- PARAMETERS: prefix
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setDbPrefix($a)
		{
			$this->prefix = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setId
		//--- PURPOSE: set object ID
		//--- PARAMETERS: id
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setId($a)
		{
			$this->id = (int) $a;
		}

		//-----------------------------------------------
		//--- METHOD: setFailDisplay
		//--- PURPOSE: set query fail output display
		//--- PARAMETERS: DB error message
		//--- RETURNS: nothing
		//-----------------------------------------------

		function setFailDisplay($error)
		{
			$this->fail_display = '<div class="pb_entry">' . "\n";
			$this->fail_display .= '<table>' . "\n";
			$this->fail_display .= "\t<tr>\n";
			$this->fail_display .= "\t\t<th align=\"right\">Database Error:</th>\n";
			$this->fail_display .= "\t</tr>\n";
			$this->fail_display .= "\t<tr>\n";
			$this->fail_display .= '<td>&nbsp;</td>' . "\n";
			$this->fail_display .= "\t</tr>\n";
			$this->fail_display .= "\t<tr>\n";
			$this->fail_display .= "\t<td>$error</td>\n";
			$this->fail_display .= "\t</tr>\n";
			$this->fail_display .= '</table>' . "\n";
			$this->fail_display .= '<form>' . "\n";
			$this->fail_display .= '</div>' . "\n";
		}



		//-----------------------------------------------
		//-----------------------------------------------
		//--- GET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: getDbPrefix
		//--- PURPOSE: get database prefix
		//--- PARAMETERS: none
		//--- RETURNS: database prefix
		//-----------------------------------------------
		function getDbPrefix()
		{
			return $this->prefix;
		}

		//-----------------------------------------------
		//--- METHOD: getId
		//--- PURPOSE: get object ID
		//--- PARAMETERS: none
		//--- RETURNS: id
		//-----------------------------------------------
		function getId()
		{
			return (int) $this->id;
		}

		//-----------------------------------------------
		//--- METHOD: getUserIp
		//--- PURPOSE: Retrieve the users remote IP Address
		//--- PARAMETERS: none
		//--- RETURNS: IP Address
		//---          FALSE on failure
		//-----------------------------------------------
		function getUserIp()
		{
			$ip = FALSE;

			if (isset($_SERVER)) {
			   if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
			       $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
			   } elseif(isset($_SERVER['HTTP_CLIENT_IP'])) {
			       $ip = $_SERVER['HTTP_CLIENT_IP'];
			   } elseif(isset($_SERVER['REMOTE_ADDR'])) {
			       $ip = $_SERVER['REMOTE_ADDR'];
			   }
			} else {
			   if (isset($_ENV['HTTP_X_FORWARDED_FOR']) && getenv('HTTP_X_FORWARDED_FOR')) {
			       $ip = getenv('HTTP_X_FORWARDED_FOR');
			   } elseif (isset($_ENV['HTTP_CLIENT_IP']) && getenv('HTTP_CLIENT_IP')) {
			       $ip = getenv('HTTP_CLIENT_IP');
			   } elseif (isset($_ENV['REMOTE_ADDR']) && getenv('REMOTE_ADDR')) {
			       $ip = getenv('REMOTE_ADDR');
			   }
			}

			return $ip;     
		}

		//-----------------------------------------------
		//--- METHOD: getIpBlocked
		//--- PURPOSE: Check if remote IP is blocked
		//--- PARAMETERS: IP Address
		//--- RETURNS: TRUE on blocked
		//---          FALSE on not blocked
		//-----------------------------------------------
		function getIpBlocked($ip)
		{
			$stat = FALSE;

			if (defined('COMMENT_BLOCK_FILE') && file_exists(COMMENT_BLOCK_FILE)) {
				$list = file(COMMENT_BLOCK_FILE);
				foreach ($list as $line) {
					$line = trim($line);

					if ($line === $ip) {
						$stat = TRUE;
						break;
					}

					$ip_octets = explode('.', $ip);
					$octets = explode('.', $line);
					if ($octets[0] != '*' && $octets[0] != $ip_octets[0]) {
						 continue;
					} elseif ($octets[0] == '*') {
						$stat = TRUE;
						break;
					} elseif ($octets[1] != '*' && $octets[1] != $ip_octets[1]) {
						 continue;
					} elseif ($octets[1] == '*') {
						$stat = TRUE;
						break;
					} elseif ($octets[2] != '*' && $octets[2] != $ip_octets[2]) {
						 continue;
					} elseif ($octets[2] == '*') {
						$stat = TRUE;
						break;
					} elseif ($octets[3] != '*' && $octets[3] != $ip_octets[3]) {
						 continue;
					} elseif ($octets[3] == '*') {
						$stat = TRUE;
						break;
					}

				}
			}

			return $stat;
		}




		//-----------------------------------------------
		//-----------------------------------------------
		//--- OTHER METHODS -----------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: writeDb
		//--- PURPOSE: update the database
		//--- PARAMETERS: query
		//---					Safe query data (optional)
		//--- RETURNS: TRUE on success
		//---          FALSE on failure
		//-----------------------------------------------
		function writeDb($query, $query_data = FALSE)
		{

			if (!is_object($this->dbObj)) {
				$this->setDbObj();
			}

			if (!is_array($query_data)) {
				$stat = $this->dbObj->query($query);
				if (!$stat) {
					echo $this->dbObj->getError();
				}
			} elseif (is_array($query_data)) {
				$stat = $this->dbObj->safeQuery($query, $query_data);
				if (!$stat) {
					echo $this->dbObj->getError();
				}
			} else {
				$stat =  FALSE;
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: buildLink
		//--- PURPOSE: build a hyperlink
		//--- PARAMETERS: link href
		//--- 				link title
		//--- 				link text
		//--- RETURNS: XHTML hyperlink
		//-----------------------------------------------
		function buildLink($href = BASE_URL, $title, $text)
		{
			return "<a href=\"$href\" title=\"$title\">$text</a>";
		}

	} //end of class
?>