<?php
/*
 This program is distributed under the terms of the GNU General Public License.
 See the README & COPYING files for more information.
 Copyright (C) 2004-2005  Kevin L. Papendick <kevinp@polarlava.com>
*/

	//--- Includes
	require_once(LIB_PATH . 'PbBase_class.php');
	require_once(LIB_PATH . 'class.phpmailer.php');
	require_once(LIB_PATH . 'Localization_class.php');

	class PbComment extends PbBase
	{
		//--- Class Variables
		var $eid;
		var $pid;
		var $name;
		var $email;
		var $url;
		var $linebreak;
		var $display;
		var $comment;
		var $timestamp;
		var $timestamp_formatted;
		var $comment_exists;
		var $ip;



		//-----------------------------------------------
		//--- CONSTRUCTOR
		//--- PURPOSE:
		//---   Create blog comment object
		//--- PARAMETERS: table prefix (optional)
		//---					comment id (optional)
		//--- RETURNS: nothing
		//-----------------------------------------------
		function PbComment($prefix = 'wl_', $id = '')
		{

			$this->PbBase($prefix);
			$this->langObj = &new Localization(I18N_LANG, './lang/');

			if (is_int($id)) {
				//--- Retrieve Data
				$this->getCommentData($id);
			}

		}


		//-----------------------------------------------
		//-----------------------------------------------
		//--- SET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: setCommentExists
		//--- PURPOSE: flag value indicates if comment
		//---				data exists for the given ID
		//--- PARAMETERS: TRUE/FALSE
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setCommentExists($a)
		{
			$this->comment_exists = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setEid
		//--- PURPOSE: set the entry id
		//--- PARAMETERS: entry id
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setEid($a)
		{
			$this->eid = (int) $a;
		}

		//-----------------------------------------------
		//--- METHOD: setPid
		//--- PURPOSE: set the parent id
		//--- PARAMETERS: parent id
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setPid($a)
		{
			$this->pid = (int) $a;
		}

		//-----------------------------------------------
		//--- METHOD: setName
		//--- PURPOSE: set coment poster name
		//--- PARAMETERS: poster name
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setName($a)
		{
			$this->name = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setEmail
		//--- PURPOSE: set coment poster email
		//--- PARAMETERS: poster email
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setEmail($a)
		{
			$this->email = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setUrl
		//--- PURPOSE: set coment poster url
		//--- PARAMETERS: poster url
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setUrl($a)
		{
			$a = (get_magic_quotes_gpc()) ? stripslashes($a) : $a;
			$a = str_replace('http://', '', $a);
			$a = str_replace('https://', '', $a);
			$a = (get_magic_quotes_gpc()) ? addslashes($a) : $a;
			$this->url = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setDisplay
		//--- PURPOSE: set display flag
		//--- PARAMETERS: display flag
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setDisplay($a)
		{
			$this->display = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setComment
		//--- PURPOSE: set coment text
		//--- PARAMETERS: comment text
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setComment($a)
		{
			$a = strip_tags($a, COMMENT_TAGS);
			$this->comment = str_replace('  ', '&nbsp;&nbsp;', $a);

			//--- Convert New Lines -> <br />
			if ($this->getLineBreak()) {
				$text_array = explode("\r\n", $this->comment);
				for ($x = 0; $x < count($text_array); $x++) {
					if (strlen($text_array[$x]) == 0) {
						$text_array[$x] = '<br /><br />';
					}
				}
				$this->comment = implode('', $text_array);
			}
		}

		//-----------------------------------------------
		//--- METHOD: setTimestamp
		//--- PURPOSE: set coment timestamp
		//--- PARAMETERS: comment timestamp
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setTimestamp($a, $formatted = FALSE)
		{
			if ($formatted) {
				$this->timestamp_formatted = $a;
			} else {
				$this->timestamp = $a;
			}
		}

		//-----------------------------------------------
		//--- METHOD: setIp
		//--- PURPOSE: set comment IP address
		//--- PARAMETERS: comment IP address
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setIp($a)
		{
			$this->ip = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setLineBreak
		//--- PURPOSE: set linebreak flag
		//--- PARAMETERS: 1/0
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setLineBreak($a)
		{
			$this->linebreak = $a;
		}






		//-----------------------------------------------
		//-----------------------------------------------
		//--- GET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: getCommentData
		//--- PURPOSE: gets  Comment data
		//--- PARAMETERS: id (optional)
		//--- RETURNS: TRUE on success
		//---          FALSE of failure
		//-----------------------------------------------
		function getCommentData($id = '')
		{
			//--- Check for ID
			if (!isset($id)) {
				$id = $this->getId();
			}

			//--- Query
			$query = "SELECT
							cid,
							pid,
							eid,
							name,
							email,
							url,
							display,
							comment,
							timestamp,
							DATE_FORMAT(timestamp, '%s') AS timestamp_formatted,
							ip
						 FROM
					 		{$this->prefix}comments
					 	 WHERE
					 	 	cid='%i'";
			$query_data = array(COMMENT_DATE_FORMAT, $id);

			//--- Issue Query
			if ($this->dbObj->safeQuery($query, $query_data)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {

					//--- Retrieve Results
					while ($this->dbObj->getRow()) {
						$this->setId($this->dbObj->row['cid']);
						$this->setPid($this->dbObj->row['pid']);
						$this->setEid($this->dbObj->row['eid']);
						$this->setName($this->dbObj->row['name']);
						$this->setEmail($this->dbObj->row['email']);
						$this->setUrl($this->dbObj->row['url']);
						$this->setDisplay($this->dbObj->row['display']);
						$this->setComment($this->dbObj->row['comment']);
						$this->setTimestamp($this->dbObj->row['timestamp']);
						$this->setTimestamp($this->dbObj->row['timestamp_formatted'], TRUE);
						$this->setIp($this->dbObj->row['ip']);
					}
					$this->setCommentExists(TRUE);

				} else {
					$this->setCommentExists(FALSE);
				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}
				return $stat;
		}


		//-----------------------------------------------
		//--- METHOD: getEid
		//--- PURPOSE: get entry id
		//--- PARAMETERS: none
		//--- RETURNS: entry id
		//-----------------------------------------------
		function getEid()
		{
			return (int) $this->eid;
		}

		//-----------------------------------------------
		//--- METHOD: getPid
		//--- PURPOSE: get parent id
		//--- PARAMETERS: none
		//--- RETURNS: parent id
		//-----------------------------------------------
		function getPid()
		{
			return (int) $this->pid;
		}

		//-----------------------------------------------
		//--- METHOD: getName
		//--- PURPOSE: get poster name
		//--- PARAMETERS: none
		//--- RETURNS: poster name
		//-----------------------------------------------
		function getName()
		{
			return $this->name;
		}

		//-----------------------------------------------
		//--- METHOD: getEmail
		//--- PURPOSE: get poster email
		//--- PARAMETERS: none
		//--- RETURNS: poster email
		//-----------------------------------------------
		function getEmail()
		{
			return $this->email;
		}

		//-----------------------------------------------
		//--- METHOD: getUrl
		//--- PURPOSE: get poster url
		//--- PARAMETERS: none
		//--- RETURNS: poster url
		//-----------------------------------------------
		function getUrl()
		{
			return $this->url;
		}

		//-----------------------------------------------
		//--- METHOD: getDisplay
		//--- PURPOSE: get comment display flag
		//--- PARAMETERS: none
		//--- RETURNS: display flag
		//-----------------------------------------------
		function getDisplay()
		{
			return $this->display;
		}

		//-----------------------------------------------
		//--- METHOD: getComment
		//--- PURPOSE: get poster comment text
		//--- PARAMETERS: mode: HTML, DO_STUPEFY
		//--- RETURNS: poster comment
		//-----------------------------------------------
		function getComment($mode = 'HTML')
		{
			if ($mode === 'DO_STUPEFY') {
				return str_replace('&nbsp;&nbsp;', '  ', $this->comment); //strip
			} else {
				return $this->comment;
			}
		}

		//-----------------------------------------------
		//--- METHOD: getTimestamp
		//--- PURPOSE: get comment timestamp
		//--- PARAMETERS: TRUE/FALSE formatted (optional)
		//--- RETURNS: comment timestamp
		//-----------------------------------------------
		function getTimestamp($formatted = FALSE)
		{
			if ($formatted) {
				$date = $this->timestamp_formatted;
			} else {
				$date = $this->timestamp;
			}
			return $date;
		}

		//-----------------------------------------------
		//--- METHOD: getIp
		//--- PURPOSE: get comment IP address
		//--- PARAMETERS: none
		//--- RETURNS: comment IP address
		//-----------------------------------------------
		function getIp()
		{
			return $this->ip;
		}

		//-----------------------------------------------
		//--- METHOD: getLineBreak
		//--- PURPOSE: get linebreak flag
		//--- PARAMETERS: none
		//--- RETURNS: linebreak flag
		//-----------------------------------------------
		function getLineBreak()
		{
			return (int) $this->linebreak;
		}

		//-----------------------------------------------
		//--- METHOD: getCommentExists
		//--- PURPOSE: flag value indicates if entry
		//---				data exists for the given ID
		//--- PARAMETERS: none
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function getCommentExists()
		{
			return $this->comment_exists;
		}




		//-----------------------------------------------
		//-----------------------------------------------
		//--- OTHER METHODS -----------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: updateComment
		//--- PURPOSE: update comment in the database
		//--- PARAMETERS: none
		//--- RETURNS: TRUE on success
		//---          FALSE on failure
		//-----------------------------------------------
		function updateComment()
		{
			if (!$this->getId() > 0) {
				return FALSE;
			}

			$stat = FALSE;
			if (USE_COMMENTS) {
				$query = "UPDATE
						 		{$this->prefix}comments
							SET
								name='%s',
								email='%s',
								url='%s',
								comment='%s',
								display='%i'
							WHERE
								cid='%i'";

				$query_data = array(
									$this->getName(),
									$this->getEmail(),
									$this->getUrl(),
									$this->getComment(),
									$this->getDisplay(),
									$this->getId()
								  );

				$this->setCommentExists(TRUE);
				$stat = $this->dbObj->safeQuery($query, $query_data);
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: insertComment
		//--- PURPOSE: insert comment in the database
		//--- PARAMETERS: none
		//--- RETURNS: TRUE on success
		//---          FALSE on failure
		//-----------------------------------------------
		function insertComment()
		{
			$stat = FALSE;

			if (USE_COMMENTS && $this->commentsEnabled($this->getEid()) && !$this->getIpBlocked($this->getUserIp())) {
				$query = "INSERT INTO
								{$this->prefix}comments
								(
								 eid,
								 pid,
								 name,
								 email,
								 url,
								 comment,
								 ip
								)
							VALUES
								(
								 '%i',
								 '%i',
								 '%s',
								 '%s',
								 '%s',
								 '%s',
								 '%s'
								)";
				$query_data = array(
									$this->getEid(),
									$this->getPid(),
									$this->getName(),
									$this->getEmail(),
									$this->getUrl(),
									$this->getComment(),
									$this->getUserIp()
								  );

				$stat = $this->dbObj->safeQuery($query, $query_data);
				if ($stat) {
					$this->setId(mysql_insert_id());
					$this->setCommentExists($stat);
				}

				if ($this->getPid() == 0) {
					$this->emailNotify($this->getName()); //comment
				} else {
					$this->emailNotify($this->getName(), FALSE); //reply
				}
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: commentsEnabled
		//--- PURPOSE: checks if comments are allowed for
		//---				an entry.
		//--- PARAMETERS: $eid
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function commentsEnabled($eid)
		{
			$stat = FALSE;
			$query = "SELECT
							comments
						 FROM
						 	{$this->prefix}entries
						 WHERE
						 	eid='%i'";
				$query_data = array($eid);

				$stat = $this->dbObj->safeQuery($query, $query_data);
				if ($stat) {
					$row = $this->dbObj->getRow();
					$stat = ((int) $row['comments']) ? TRUE : FALSE;
				}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: deleteComment
		//--- PURPOSE: update entry data in the database
		//--- PARAMETERS: none
		//--- RETURNS: TRUE on success
		//---          FALSE on failure
		//-----------------------------------------------
		function deleteComment()
		{
			if (!$this->getId() > 0) {
				return FALSE;
			}

			$cids = array();
			$cids = $this->findDeletes($this->getId());
			$cids[] = $this->getId();
			$query_data = array($cids, $cids);

			$query = "DELETE FROM
					 		{$this->prefix}comments
						WHERE
							cid IN (%c)
						OR
							pid IN (%c)";

			$this->setCommentExists(FALSE);

			return $this->writeDb($query, $query_data);
		}

		//-----------------------------------------------
		//--- METHOD: findDeletes
		//--- PURPOSE: find all decedents of comment to delete
		//--- PARAMETERS: comment id
		//--- RETURNS: array of comment id's
		//-----------------------------------------------
		function findDeletes($cid)
		{
			$cids = array();
			$query = "SELECT
							cid
						 FROM
					 		{$this->prefix}comments
						 WHERE
							pid='%i'";
			$query_data = array($cid);

			if ($this->dbObj->safeQuery($query, $query_data)) {
				if ($this->dbObj->result_cnt > 0) {
					while ($this->dbObj->getRow()) {
						$cids[] = $this->dbObj->row['cid'];
					}
					$tmp_cids = $cids; // necessary, because we're modifying $cids
					foreach ($tmp_cids as $tmp_cid) {
						$cids = array_merge($cids, $this->findDeletes($tmp_cid));
					}
				}
			} else {
				echo $this->dbObj->getError();
			}

			return $cids;
		}

		//-----------------------------------------------
		//--- METHOD: emailNotify
		//--- PURPOSE: notify commentor of reply
		//--- PARAMETERS: commentor/replier name
		//---					comment/reply flag
		//--- RETURNS: nothing
		//-----------------------------------------------
		function emailNotify($by_name, $comment = TRUE)
		{
			$mail_debug_msg = '';
			$blog_name = (defined('BLOG_NAME')) ? BLOG_NAME : 'PolarBlog';
			if ($comment) {
				$mail_subject = stripslashes(strip_tags($blog_name)) . ' ' . $this->langObj->get('MAIL_SUBJECT_COMMENT') . ': ';
				$mail_msg = $this->langObj->get('MAIL_COMMENT_INTRO') . ' ';
				$query = "SELECT
								u.post_by AS name,
								u.email,
								e.title
							 FROM
								{$this->prefix}entries AS e,
								{$this->prefix}users AS u
							 WHERE
								e.eid='%i'
							 AND
								u.id=e.uid;";
				$query_data = array(
									$this->getEid()
								  );
			} else {
				$mail_subject = stripslashes(strip_tags($blog_name)) . ' ' . $this->langObj->get('MAIL_SUBJECT_REPLY') . ': ';
				$mail_msg = $this->langObj->get('MAIL_REPLY_INTRO') . ' ';
				$query = "SELECT
							c.name,
							c.email,
							e.title
						  FROM
						  	{$this->prefix}comments AS c,
							{$this->prefix}entries AS e
						  WHERE
						  	cid='%i'
						  AND
							e.eid=c.eid";
				$query_data = array(
									$this->getPid()
								  );
			}

			if ($this->dbObj->safeQuery($query, $query_data)) {
				$row = $this->dbObj->getRow();
				$mail_subject .= $row['title'];
				$mail_msg = str_replace('::NAME::', $by_name, $mail_msg);
				$mail_msg .= $row['title'] . ' ' . $this->langObj->get('MAIL_OUTRO') . ': ';
				$mail_msg .= BASE_URL . '?eid=' . $this->getEid() . '#' . $this->getId() . "\r\n\r\n";
				$mail_msg .= '--- ' . $this->langObj->get('MAIL_THE_COMMENT') . ":\r\n";

				//--- Convert <br /> -> "\r\n"
				$the_comment = str_replace('<br />', "\r\n", $this->getComment('DO_STUPEFY'));
				$mail_msg .= stripslashes(strip_tags($the_comment)) . "\r\n\r\n\r\n";

				$for = $blog_name;
				$for .= ' (' . BASE_URL . ')';
				$for = stripslashes(strip_tags($for));
				$mail_msg .= $this->langObj->get('MAIL_TAG') . " $for.\r\n";

				if (defined('COMMENT_MAIL') && COMMENT_MAIL) {
					$mail = &new PHPMailer();
					if (defined('MAIL_HOST')) {
						$mail->Host = MAIL_HOST;
						$mail_debug_msg = $mail->ErrorInfo . '<br />';
					}
					$mail->Mailer = MAIL_TYPE;
					$mail_debug_msg .= $mail->ErrorInfo . '<br />';
					$mail->From = MAIL_FROM;
					$mail_debug_msg .= $mail->ErrorInfo . '<br />';
					$mail->FromName = MAIL_FROM_NAME;
					$mail_debug_msg .= $mail->ErrorInfo . '<br />';
					$mail->Subject = $mail_subject;
					$mail_debug_msg .= $mail->ErrorInfo . '<br />';

					$send_mail = FALSE;
					if (strlen($row['email']) > 0) {
						$mail->AddAddress($row['email'], $row['name']);
						$mail->AddReplyTo($row['email'], $row['name']);
						$mail_debug_msg .= $mail->ErrorInfo . '<br />';
						$send_mail = TRUE;
					}
					if (!$comment && defined('MAIL_BCC_REPLY')) {
						if (strlen($row['email']) > 0) {
							$mail->AddBCC(MAIL_FROM, MAIL_FROM_NAME);
							$mail_debug_msg .= $mail->ErrorInfo . '<br />';
						} else {
							$mail->AddAddress(MAIL_FROM, MAIL_FROM_NAME);
							$mail_debug_msg .= $mail->ErrorInfo . '<br />';
						}
						$send_mail = TRUE;
					}
					$mail->Body = $mail_msg;
					$mail_debug_msg .= $mail->ErrorInfo . '<br />';

					if ($send_mail) {
						$stat = $mail->Send();
					}

					if (defined('MAIL_DEBUG') && MAIL_DEBUG) {
						echo 'Mail Debug:<br />' . $mail_debug_msg;
					}
				}
			}
		}

	} //end of class
?>