<?php
/*
 This program is distributed under the terms of the GNU General Public License.
 See the README & COPYING files for more information.
 Copyright (C) 2004-2005  Kevin L. Papendick <kevinp@polarlava.com>
*/

	//--- Includes
	require_once(LIB_PATH . 'PbBase_class.php');
	require_once(LIB_PATH . 'PbUser_class.php');
	require_once(LIB_PATH . 'PbTopic_class.php');
	require_once(LIB_PATH . 'PbEntry_class.php');
	require_once(LIB_PATH . 'Localization_class.php');
	if (defined('USE_GIGGLE') && USE_GIGGLE) {
		require_once(GIGGLE_LIB_PATH . 'phpgiggle.inc.php');
	}

	class PolarBlog extends PbBase
	{
		//--- Class Variables
		var $entries;
		var $entry_cnt;
		var $users;
		var $topics;
		var $display;
		var $accessory_display;
		var $fail_display;
		var $display_cnt;
		var $index_mode;
		var $separator_date;
		var $comment_indent;



		//-----------------------------------------------
		//--- CONSTRUCTOR
		//--- PURPOSE:
		//---   Create blog entry object
		//--- PARAMETERS: table prefix (optional)
		//--- RETURNS: nothing
		//-----------------------------------------------
		function PolarBlog($prefix = 'wl_')
		{
			$this->PbBase($prefix);
			$this->entries = array();
			$this->topics = array();
			$this->setTopics();
			$this->langObj = &new Localization(I18N_LANG, './lang/');
		}


		//-----------------------------------------------
		//-----------------------------------------------
		//--- SET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: setCommentIndent
		//--- PURPOSE: set the comment indent value
		//--- PARAMETERS: indent in pixels
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setCommentIndent($a)
		{
			$this->comment_indent = $a;
		}

		//-----------------------------------------------
		//--- METHOD: setDisplayCnt
		//--- PURPOSE: set entries to display
		//--- PARAMETERS: count (optional)
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setDisplayCnt($cnt = -1)
		{
			if ($cnt == -1) {
				$this->display_cnt = DEFAULT_DISPLAY_CNT;
			} else {
				$this->display_cnt = $cnt;
			}
		}

		//-----------------------------------------------
		//--- METHOD: setDisplay
		//--- PURPOSE: set output display
		//--- PARAMETERS: start id
		//--- 				entry id (optional);
		//--- 				entry date (optional);
		//--- 				topic id (optional);
		//--- 				search string (optional);
		//--- 				footer_enabled (optional);
		//--- 				comment mode (optional);
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function setDisplay($start = 0, $eid = FALSE, $date = FALSE, $tid = FALSE, $search = FALSE, $footer_enabled = TRUE, $comment_mode = FALSE)
		{
			$this->setDisplayCnt();
			$this->index_mode = FALSE;

			//--- Display Single Entry
			$full_entry = FALSE;
			if (is_int($tid)) {
				//--- Topic Specific Entries
				$stat = $this->setEntries($start, FALSE, $tid);
			} elseif (is_int($eid)) {
				$this->entries[0] = &new PbEntry($this->getDbPrefix(), $eid);
				$full_entry = TRUE;
				$stat = ($this->entries[0] === 'Object') ? TRUE : FALSE;
			} elseif (is_int($date)) {
				//--- Date Specific Entries
				$stat = $this->setEntries($date, TRUE);
			} elseif (strlen($search) > 0) {
				//--- Search Entries
				$stat = $this->searchEntries($tid, $search);
				$stat = (isset($this->entries[0]) && $this->entries[0] === 'Object') ? TRUE : FALSE;
			} else {
				//--- Default: Display Last x Entries
				if ($start == 0) {
					$stat = $this->setEntries();
				} else {
					//--- Begin at offset
					$stat = $this->setEntries($start);
				}
			}

			//--- Build Display
			if (count($this->entries) > 0) {
				foreach ($this->entries as $entry) {
					if ($entry->getEntryExists()) {
						if (defined('USE_TIMER') && USE_TIMER) {
							require_once(LIB_PATH . 'Timer.php');
							$timer = &new Timer();
							$etime_total = (!isset($etime_total)) ? 0 : $etime_total;
						}
						$this->display .= $this->buildEntry(&$entry, $full_entry, $footer_enabled);
						if (defined('USE_TIMER') && USE_TIMER) {
							$proc_time = $timer->getPageTime();
							$etime_total += $timer->getPageTime('seconds');
							$this->display .= '<!-- Entry Time: ' . $proc_time . " -->\n";
							$this->display .= '<!-- Cumulative Entry Time: ' . $etime_total . " seconds -->\n";
						}

						//--- Include Comments
						if ($full_entry && USE_COMMENTS && !$comment_mode) {
							$this->display .= '<div><a name="comments"></a></div>';
							$this->display .= $this->buildComments(&$entry);
						}
					} elseif (count($this->entries) && $entry->getId()) {
						$this->display = '<div class="pb_entry">';
						$this->display .= '<p class="pb_body">' . $this->langObj->get('NO_ENTRY_DATA') . " $eid.<br /></p>";
						$this->display .= '</div>';
					} else {
						$this->display = '<div class="pb_entry">';
						$this->display .= '<p class="pb_body">' . $this->langObj->get('NO_ENTRY_ID') . " $eid.<br /></p>";
						$this->display .= '</div>';
					}
				}
			} elseif (count($this->entries) == 0 && strlen($search) > 0) {
				$this->display = '<div class="pb_entry">';
				$this->display .= '<p class="pb_body">' . $this->langObj->get('NO_SEARCH_RESULT') . ':<br /><br />';
				$this->display .= '<span class="pb_search_fail">' . htmlentities(stripslashes($search)) . '</span>';
				$this->display .= '<br /><br />' . $this->langObj->get('SEARCH_AGAIN') . '</p>';
				$this->display .= '</div>';
			} else {
				$this->display = '<div class="pb_entry">';
				$this->display .= '<p class="pb_body">' . $this->langObj->get('NO_ENTRIES') . '<br /></p>';
				$this->display .= '</div>';
			}
			if ($footer_enabled) {
			$this->display .= $this->buildNavBar($start, $search, $tid);
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setAccessoryDisplay
		//--- PURPOSE: set calendar & header output display
		//--- PARAMETERS: calendar month (optional)
		//--- 				calendar year (optional);
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setAccessoryDisplay($month = 'now', $year = 'now')
		{

			if (defined('CSS') && USE_NAV) {
				$nav_file = file(NAV_FILE);
				$this->accessory_display .= '<div id="Nav">';
				foreach ($nav_file as $line) {
					$this->accessory_display .= $line;
				}
				$this->accessory_display .= '</div>';
			}

			if (defined('TOP_HEADER')) {
				$this->accessory_display .= '<div id="PbTopHeader" class="pb_nav-bar">';
				$this->accessory_display .= TOP_HEADER;
				$this->accessory_display .= '</div>';
			}

			if (defined('SUB_HEADER')) {
				$this->accessory_display .= '<div id="PbSubHeader" class="pb_sh_h1">';
				$this->accessory_display .= SUB_HEADER;
				$this->accessory_display .= '</div>';
			}
			if (defined('BLOG_TAGLINE')) {
				$this->accessory_display .= '<div class="pb_tagline">';
				$this->accessory_display .= BLOG_TAGLINE;
				$this->accessory_display .= '</div>';
			}
			if (defined('USE_TIMER') && USE_TIMER) {
				require_once(LIB_PATH . 'Timer.php');
				$timer = &new Timer();
			}
			$this->accessory_display .= '<div id="PbCalendar" class="pb_nav-bar">';
			$this->accessory_display .= $this->buildCalendar($month, $year);
			$this->accessory_display .= '<hr />';

			if ($this->index_mode) {
				$this->accessory_display .= $this->buildLink('?index=0', ENTRY_LINK, ENTRY_LINK);
			} else {
				$this->accessory_display .= $this->buildLink('?index=1', ARCHIVE_LINK, ARCHIVE_LINK);
			}

			$this->accessory_display .= '<br />';
			$this->accessory_display .= '<hr />';


			$this->accessory_display .= $this->setAdminMenu();
			$this->accessory_display .= $this->setRecentLinks();
			$this->accessory_display .= $this->setTopicLinks();
			$this->accessory_display .= $this->setOtherBlogs();
			$this->accessory_display .= $this->setTagLinks();

			$this->accessory_display .= "</div>\n";
			if (defined('USE_TIMER') && USE_TIMER) {
				$proc_time = $timer->getPageTime();
				$this->accessory_display .= '<!-- Calendar Time: ' . $proc_time . " -->\n";
			}
		}

		//-----------------------------------------------
		//--- METHOD: setAdminMenu
		//--- PURPOSE: set administrative links
		//--- PARAMETERS: none
		//--- RETURNS: XHTML string
		//-----------------------------------------------
		function setAdminMenu()
		{
			$links = '';
			if (defined('USE_LOGIN_LINK') && USE_LOGIN_LINK && !(isset($_SESSION['login']) && $_SESSION['login'])) {
				$links .= $this->langObj->get('ADMINISTRATION');
				$links .= '<br />';
				$links .= $this->buildLink('?login=1', $this->langObj->get('PB_LOGIN'), '[' . $this->langObj->get('LOGIN') . ']');
				$links .= '<hr />';
			} elseif (isset($_SESSION['login']) && $_SESSION['login']) {
				$links .= $this->langObj->get('ADMINISTRATION');
				$links .= '<br />';
				if (isset($_SESSION['post_entry']) && $_SESSION['post_entry']) {
					$links .= '&nbsp;' . $this->buildLink('?admin=add', $this->langObj->get('ADD_NEW_ENTRY'), '[' . $this->langObj->get('ADD_ENTRY') .']') . '<br />';
				}
				if (isset($_SESSION['admin']) && $_SESSION['admin']) {
					$links .= '&nbsp;' . $this->buildLink('?admin=topics', $this->langObj->get('EDIT_AVAIL_TOPIC'), '[' . $this->langObj->get('EDIT_TOPICS') .']') . '<br />';
					$links .= '&nbsp;' . $this->buildLink('?admin=users', $this->langObj->get('EDIT_USERS'), '[' . $this->langObj->get('EDIT_USERS') . ']') . '<br />';
				}
				$links .= '&nbsp;' . $this->buildLink('?logout=1', $this->langObj->get('LOGOUT'), '[' . $this->langObj->get('LOGOUT') . ']') . '<br />';
				$links .= '<hr />';
			}

			return $links;
		}

		//-----------------------------------------------
		//--- METHOD: setTagLinks
		//--- PURPOSE: set tag list links
		//--- PARAMETERS: none
		//--- RETURNS: XHTML string
		//-----------------------------------------------
		function setTagLinks()
		{
			global $config;

			if (!defined('USE_TAG_GROUPS') || USE_TAG_GROUPS == FALSE) { return; }

			$links = '';
			$cnt = 0;
			$group_cnt = count($config['tags']);
			foreach ($config['tags'] as $group) {
				$cnt++;
				foreach($group as $tag) {
					$img = '<img class="pb_no_border" src="' . $tag['image'] . '" alt="' . $tag['title'] . '" />';
					$links .= $this->buildLink($tag['url'], $tag['title'], $img);
					$links .= '<br />';
				}
				if ($cnt < $group_cnt) {
					$links .= '<hr />';
				}
			}

			return $links;
		}

		//-----------------------------------------------
		//--- METHOD: setOtherBlogs
		//--- PURPOSE: set links to other blogs
		//--- PARAMETERS: none
		//--- RETURNS: XHTML string
		//-----------------------------------------------
		function setOtherBlogs()
		{
			global $config;

			if (!defined('USE_OTHER_BLOGS') || USE_OTHER_BLOGS == FALSE) { return; }

			if (defined('OTHER_BLOGS_TITLE') && OTHER_BLOGS_TITLE) {
				$links = OTHER_BLOGS_TITLE;
				$links .= '<ul>';
				foreach ($config['blogs'] as $blog) {
					$links .= '<li> ' . $this->buildLink($blog['url'], $blog['title'] . ' - ' . $blog['desc'], $blog['title']) . '</li>';
				}
				$links .= '</ul>';
			} else {
				$links = '';
				$current_section = '';
				foreach ($config['blogs'] as $section => $blogs) {
					if ($section != $current_section) {
						$links .= $section;
						$current_section = $section;
					}

					$links .= '<ul>';
					foreach ($blogs as $blog) {
						$links .= '<li> ' . $this->buildLink($blog['url'], $blog['title'] . ' - ' . $blog['desc'], $blog['title']) . '</li>';
					}
					$links .= '</ul>';
				}
			}
			$links .= '<hr />';

			return $links;
		}

		//-----------------------------------------------
		//--- METHOD: setTopicLinks
		//--- PURPOSE: set links to blog topics
		//--- PARAMETERS: none
		//--- RETURNS: XHTML string
		//-----------------------------------------------
		function setTopicLinks()
		{
			if (!defined('USE_TOPIC_LINKS') || USE_TOPIC_LINKS == FALSE) { return; }

			$links = $this->langObj->get('TOPICS');
			$links .= '<ul>';
			foreach ($this->topics as $topicObj) {
				$links .= '<li> ' . $this->buildLink(BASE_URL . '?tid=' . $topicObj->getId(), $this->langObj->get('TOPIC') . ': ' . $topicObj->getName(), $topicObj->getName()) . '</li>';
			}
			$links .= '</ul>';
			$links .= '<hr />';

			return $links;
		}

		//-----------------------------------------------
		//--- METHOD: setRecentLinks
		//--- PURPOSE: set recent story links
		//--- PARAMETERS: none
		//--- RETURNS: XHTML string
		//-----------------------------------------------
		function setRecentLinks()
		{
			if (!defined('DEFAULT_RECENT_CNT') || DEFAULT_RECENT_CNT == 0) { return; }

			$entries = array();
			$display_flag = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? " WHERE display='1'" : '';
			$post_dated = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? 'AND updated<=UNIX_TIMESTAMP()' : '';
			$limit = DEFAULT_RECENT_CNT;
			$query = "SELECT
							eid
						 FROM
					 		{$this->prefix}entries
					 	 $display_flag
					 	 $post_dated
					 	 ORDER BY
					 	 	updated
					 	 DESC
					 	 LIMIT $limit";

			//--- Issue Query
			if ($this->dbObj->query($query)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {
					//--- Retrieve Results
					$i = 0;
					while ($this->dbObj->getRow()) {
						$eid = (int) $this->dbObj->row['eid'];
						$entries[$i] = &new PbEntry($this->getDbPrefix(), $eid);
						$i++;
					}
				}

				$stat = TRUE;

			} else {
				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			$links = '';
			if ($stat) {
				$links .= $this->langObj->get('RECENT_ENTRIES');
				$links .= '<ul>';
				foreach ($entries as $entry) {
					$topicObj = $this->topics[$entry->getTopicId()];
					$topic = $topicObj->getName();
					$links .= '<li> ' . $this->buildLink('?eid=' . $entry->getId(), $entry->getUpdated(TRUE) . ' - ' . $topic . ': ' . $entry->getTitle(), $entry->getTitle()) . '</li>';
				}
				$links .= '</ul>';
				$links .= '<hr />';
			}
			return $links;
		}

		//-----------------------------------------------
		//--- METHOD: setIndexDisplay
		//--- PURPOSE: set archive index output display
		//--- PARAMETERS: index start id
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function setIndexDisplay($start = 0)
		{
			$this->setDisplayCnt(DEFAULT_ARCHIVE_CNT);
			$this->index_mode = TRUE;

			//--- Display Index
			$stat = $this->setEntries($start);

			//--- Build Display
			/* PAGING
			if (count($this->entries) > 0 && strlen($search) > 0) {
				for ($i = 0; $i < $this->getEntryCnt(); $i++) {
					$this->display .= $this->buildEntry($this->entries[$i], $full_entry);
				}
			} else
			*/

			if (count($this->entries) > 0) {
				$search = FALSE; //clear search results from nav bar so display recent selected works after a search.
				$this->display .= $this->buildIndex();
			} else {
				$this->display = '<div class="pb_entry">';
				$this->display .= '<p class="pb_body">' . $this->langObj->get('NO_ENTRIES') . '</p>';
				$this->display .= '</div>';
			}
			$this->display .= $this->buildNavBar($start, FALSE);

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setEditDisplay
		//--- PURPOSE: set edit/add output display
		//--- PARAMETERS: entry id
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------

		function setEditDisplay($eid)
		{

			//--- Edit or Add?
			$this->entries[0] = &new PbEntry($this->getDbPrefix(), $eid);
			$stat = ($this->entries[0] === 'Object') ? TRUE : FALSE;

			//--- Set fields
			$dupe_id = md5(uniqid(rand(), true));
			$_SESSION['dupe_id'] = $dupe_id;
			$title = ($eid) ? $this->entries[0]->getTitle() : '';
			$topic_id = ($eid) ? $this->entries[0]->getTopicId() : 0;
//			$body = ($eid) ? htmlentities($this->entries[0]->getBody('DO_STUPEFY')) : '';
//			$more = ($eid && $this->entries[0]->getMoreExists()) ? htmlentities($this->entries[0]->getMore('DO_STUPEFY')) : '';
			$body = ($eid) ? $this->entries[0]->getBody('DO_STUPEFY') : '';
			$more = ($eid && $this->entries[0]->getMoreExists()) ? $this->entries[0]->getMore('DO_STUPEFY') : '';
			$ping = (USE_PINGER && !$eid) ? ' checked="checked"' : '';
			if ($eid && $this->entries[0]->getDisplay()) {
				$display_entry = ' checked="checked"';
			} elseif ($eid && !$this->entries[0]->getDisplay()) {
				$display_entry = '';
			} elseif (defined('DISPLAY_ENTRY_DEFAULT') && DISPLAY_ENTRY_DEFAULT) {
				$display_entry = ' checked="checked"';
			} else {
				$display_entry = '';
			}

			if ($eid && $this->entries[0]->getAllowComments()) {
				$allow_comments = ' checked="checked"';
			} elseif ($eid && !$this->entries[0]->getAllowComments()) {
				$allow_comments = '';
			} else {
				$allow_comments = ' checked="checked"';
			}

			//--- Set Headers
			if (defined('TOP_HEADER')) {
				$this->accessory_display .= '<div id="PbTopHeader" class="pb_nav-bar">';
				$this->accessory_display .= TOP_HEADER;
				$this->accessory_display .= '</div>';
			}
			$this->accessory_display .= '<div id="PbSubHeader" class="pb_sh_h1">';
			$this->accessory_display .= $this->langObj->get('PB_ENTRY');
			$this->accessory_display .= '</div>';

			//--- Set Display
			$this->display = '<div class="pb_edit">';
			$this->display .= '<form action="' . BASE_URL . '" method="post" name="entry_form">' . "\n";
			$this->display .= "\n\t" . '<p class="pb_created"><span class="pb_input_text">' . $this->langObj->get('TOPIC') . ':</span> ';
			// Topic
			if (isset($this->topics) && count($this->topics) > 0) {
				$this->display .= "\t\t<select name=\"tid\">\n";
				foreach ($this->topics as $id => $obj) {
					$sel = ($topic_id == $id) ? ' selected="selected"' : '';
					$this->display .= "\t\t <option value=\"$id\"$sel>" . $obj->getName() . "</option>\n";
				}
				$this->display .= "\t\t</select>\n";
			} else {
				$this->display .= $this->langObj->get('ADD_ONE_TOPIC') . "\n";
			}
			$this->display .= "<br />\n";
			// Title
			$this->display .= "\n\t" . '<span class="pb_input_text">' . $this->langObj->get('TITLE') . ':</span>&nbsp;&nbsp;';
			$this->display .= "\t\t <input type=\"text\" name=\"title\" value=\"$title\" size=\"50\" />\n";
			$this->display .= "<br />\n";
			// Body
			$this->display .= "\t" . '<span class="pb_input_text">' . $this->langObj->get('BODY') . ":</span><br />\n";
			$this->display .= "\t<textarea name=\"body\" rows=\"" . EDIT_BODY_ROWS . '" cols="' . EDIT_COLS . "\">$body</textarea></p>\n";
			// More
			$this->display .= "\t" . '<p class="pb_created"><span class="pb_input_text">' . $this->langObj->get('MORE') . ":</span><br />\n";
			$this->display .= "\t" . '<textarea name="more" rows="' . EDIT_MORE_ROWS . '" cols="' . EDIT_COLS . "\">$more</textarea>\n<br />\n";
			// Timestamp & Time Adjust
			if ($eid) {
				//--- Edit Mode
				$button_text = $this->langObj->get('UPDATE_ENTRY');
				$edit_mode = 'update';
				$this->display .= "\t\t" . '<span class="pb_input_text">' . $this->langObj->get('TIMESTAMP') . ':</span>&nbsp;<input type="checkbox" name="create_timestamp" value="1" /><span class="pb_input_text">' . $this->langObj->get('RESET_CREATE') . "</span>\n";
				$this->display .= "\n\t" . '&nbsp;||&nbsp;<input type="checkbox" name="update_timestamp" value="1" /><span class="pb_input_text">' . $this->langObj->get('SET_UPDATE') . "</span>\n";
				$this->display .= "\n\t" . '&nbsp;||&nbsp;<span class="pb_input_text"> ' . $this->langObj->get('ADJUST') . ":</span> \n";
			} else {
				//--- Add Mode
				$button_text = $this->langObj->get('ADD_ENTRY');
				$edit_mode = 'insert';
				$this->display .= "<input type=\"hidden\" name=\"create_timestamp\" value=\"1\" />\n";
				$this->display .= "\n\t" . '<span class="pb_input_text">' . $this->langObj->get('TIMESTAMP_ADJUST') . ":</span> \n";
			}
			$this->display .= "\t\t<input type=\"radio\" name=\"time_adj_dir\" value=\"+\" />+\n";
			$this->display .= "\t\t<input type=\"radio\" name=\"time_adj_dir\" value=\"-\" checked=\"checked\" />-\n";
			$this->display .= "\t\t<select name=\"time_adj_hour\">\n";
			for ($i = 0; $i <= 24; $i++) {
				$this->display .= "\t\t <option value=\"$i\">$i</option>\n";
			}
			$this->display .= "\t\t</select>" . $this->langObj->get('HRS_ABRV') . "\n";
			$this->display .= "\t\t<select name=\"time_adj_min\">\n";
			for ($i = 0; $i <= 59; $i++) {
				$this->display .= "\t\t <option value=\"$i\">$i</option>\n";
			}
			$this->display .= "\t\t</select>" . $this->langObj->get('MINS_ABRV') . "\n";
			$this->display .= "<br />\n";
			// Line Breaks, Display & Save
			$this->display .= "\t\t" . '&nbsp;&nbsp;<input type="checkbox" name="linebreak" value="1" checked="checked" /><span class="pb_input_text">' . $this->langObj->get('AUTO_BREAK') . "</span>\n";
			$this->display .= "\t\t" . '&nbsp;&nbsp;<input type="checkbox" name="display" value="1"' . $display_entry . ' /><span class="pb_input_text">' . $this->langObj->get('DISPLAY_ENTRY') . "</span>\n";
			$this->display .= "\t\t" . '&nbsp;&nbsp;<input type="checkbox" name="allow_comments" value="1"' . $allow_comments . ' /><span class="pb_input_text">' . $this->langObj->get('ALLOW_COMMENTS') . "</span>\n";
			if (USE_PINGER) {
				$this->display .= "\t\t" . '&nbsp;&nbsp;<input type="checkbox" name="ping" value="1"' . $ping . ' /><span class="pb_input_text">Ping-O-Matic!' . "</span>\n";
			}
			$this->display .= "<br />\n";
			if (isset($this->topics) && count($this->topics) > 0) {
				$preview_width = PREVIEW_WIDTH;
				$preview_height = PREVIEW_HEIGHT;
				$this->display .= "\t" . '&nbsp;&nbsp;<input type="button" name="preview" value="' . $this->langObj->get('PREVIEW') . "\" onclick=\"entryPreview('entry_preview.php', $preview_width, $preview_height)\" />\n";
				$this->display .= "\t&nbsp;&nbsp;<input type=\"submit\" name=\"edit\" value=\"$button_text\" />\n";
			} else {
				$this->display .= "\t" . '&nbsp;&nbsp;' . $this->langObj->get('NO_TOPIC_NO_POST') . "\n";
			}
			if (defined('USE_SPELLER') && USE_SPELLER) {
				$this->display .= "\t" . '&nbsp;&nbsp;<input type="button" name="spell_check" value="' . $this->langObj->get('CHECK_SPELLING') . '" onClick="openSpellChecker();" />' . "\n";
			}
			$this->display .= "\t" . '&nbsp;&nbsp;<input type="submit" name="cancel" value="' . $this->langObj->get('CANCEL') . '" />' . "\n";
			$this->display .= "\t<input type=\"hidden\" name=\"dupe_id\" value=\"$dupe_id\" />\n";
			$this->display .= "\t<input type=\"hidden\" name=\"eid\" value=\"$eid\" />\n";
			$this->display .= "\t<input type=\"hidden\" name=\"edit_mode\" value=\"$edit_mode\" />\n";
			$this->display .= "<br />\n";
			$this->display .= ' </p></form>' . "\n";
			$this->display .= '</div>' . "\n";

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setEditUserDisplay
		//--- PURPOSE: set user edit output display
		//--- PARAMETERS: user id
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------

		function setEditUserDisplay($id)
		{
			$this->setUsers();

			//--- Set Headers
			if (defined('TOP_HEADER')) {
				$this->accessory_display .= '<div id="PbTopHeader" class="pb_nav-bar">';
				$this->accessory_display .= TOP_HEADER;
				$this->accessory_display .= '</div>';
			}
			$this->accessory_display .= '<div id="PbSubHeader" class="pb_sh_h1">';
			$this->accessory_display .= $this->langObj->get('PB_USER_ADMIN');
			$this->accessory_display .= '</div>';

			//--- Set Display
			$this->display = '<div class="pb_edit">';
			$this->display .= '<form action="' . BASE_URL . '" method="post">' . "\n";

			if ($id) {
				//--- Add/Edit User
				$edit_mode = ($id == -1) ? 'user_insert' : 'user_update';
				$userObj = &new PbUser($this->getDbPrefix(), $id);

				$this->display .= "\t<table class=\"pb_created\">\n";
				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('USER') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="text" name="user" size="30" value="' . $userObj->getUser() . "\" /></td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('PASSWORD') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="password" size="30" name="password" value="" /></td>' . "\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('PASSWORD_HINT') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="text" name="hint" size="50" value="' . $userObj->getHint() . "\" /></td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('POSTED_BY') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="text" name="post_by" size="30" value="' . $userObj->getPostBy() . "\" /></td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('EMAIL') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="text" name="email" size="50" value="' . $userObj->getEmail() . "\" /></td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('POP3_ALT_EMAIL') . ":</td>\n";
				$this->display .= "\t\t" . ' <td><input type="text" name="pop3_alt_email" size="50" value="' . $userObj->getPop3AltEmail() . "\" /></td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('ALLOW_POSTS') . "</td>\n";
				$chk_y = ($userObj->getPostEntry()) ? ' checked="checked"' : '';
				$chk_n = (!$userObj->getPostEntry()) ? ' checked="checked"' : '';
				$this->display .= "\t\t <td>\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"post_entry\" value=\"1\"$chk_y />" . $this->langObj->get('YES') . "\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"post_entry\" value=\"0\"$chk_n />" . $this->langObj->get('NO') . "\n";
				$this->display .= "\t\t </td>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('ALLOW_POP3') . "</td>\n";
				$chk_y = ($userObj->getPop3()) ? ' checked="checked"' : '';
				$chk_n = (!$userObj->getPop3()) ? ' checked="checked"' : '';
				$this->display .= "\t\t <td>\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"pop3\" value=\"1\"$chk_y />" . $this->langObj->get('YES') . "\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"pop3\" value=\"0\"$chk_n />" . $this->langObj->get('NO') . "\n";
				$this->display .= "\t\t </td>\n";

				$this->display .= "\t\t</tr>\n";
				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('ALLOW_USER_COMMENTS') . "</td>\n";
				$chk_y = ($userObj->getPostComment()) ? ' checked="checked"' : '';
				$chk_n = (!$userObj->getPostComment()) ? ' checked="checked"' : '';
				$this->display .= "\t\t <td>\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"post_comment\" value=\"1\"$chk_y />" . $this->langObj->get('YES') . "\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"post_comment\" value=\"0\"$chk_n />" . $this->langObj->get('NO') . "\n";
				$this->display .= "\t\t </td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('ADMINISTRATOR') . "</td>\n";
				$chk_y = ($userObj->getAdmin()) ? ' checked="checked"' : '';
				$chk_n = (!$userObj->getAdmin()) ? ' checked="checked"' : '';
				$this->display .= "\t\t <td>\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"admin\" value=\"1\"$chk_y />" . $this->langObj->get('YES') . "\n";
				$this->display .= "\t\t \t<input type=\"radio\" name=\"admin\" value=\"0\"$chk_n />" . $this->langObj->get('NO') . "\n";
				$this->display .= "\t\t </td>\n";
				$this->display .= "\t\t</tr>\n";

				$add_update_button = $this->langObj->get('CREATE_USER');
				if ($edit_mode === 'user_update') {
					$this->display .= "\t\t<tr>\n";
					$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('CREATED') . ":</td>\n";
					$this->display .= "\t\t <td>" . $userObj->getTimestamp() . "</td>\n";
					$this->display .= "\t\t</tr>\n";
					$add_update_button = $this->langObj->get('UPDATE_USER');
				}

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t <td>&nbsp;</td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t <td colspan=\"2\">\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="edit" value="' . $add_update_button . "\" />\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="user_delete" value="' . $this->langObj->get('DELETE_USER') . "\" onclick=\"return confirm('" . $this->langObj->get('CONFIRM_DELETE_USER') . "')\" />\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="cancel" value="' . $this->langObj->get('CANCEL') . "\" />\n";
				$this->display .= "\t\t \t<input type=\"hidden\" name=\"id\" value=\"$id\" />\n";
				$this->display .= "\t\t \t<input type=\"hidden\" name=\"edit_mode\" value=\"$edit_mode\" />\n";
				$this->display .= "\t\t \t<input type=\"hidden\" name=\"cancel_mode\" value=\"users\" />\n";
				$this->display .= "\t\t </td>\n";
				$this->display .= "\t\t</tr>\n";

			} else {
				//--- User Selector
				$this->display .= "\t<table class=\"pb_created\">\n";
				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t" . ' <td class="pb_input_text">' . $this->langObj->get('USER') . "</td>\n";
				$this->display .= "\t\t <td>\n";
				$this->display .= "\t\t \t<select name=\"id\">\n";
				$this->display .= "\t\t \t " . '<option value="-1">' . $this->langObj->get('OPTION_NEW_USER') . "</option>\n";
				foreach ($this->users as $id => $obj) {
					$this->display .= "\t\t \t <option value=\"$id\">" . $obj->getUser() . "</option>\n";
				}
				$this->display .= "\t\t \t</select>\n";
				$this->display .= "\t\t </td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t <td>&nbsp;</td>\n";
				$this->display .= "\t\t</tr>\n";

				$this->display .= "\t\t<tr>\n";
				$this->display .= "\t\t <td colspan=\"2\">\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="edit" value="' . $this->langObj->get('EDIT_USER') . "\" />\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="cancel" value="' . $this->langObj->get('CANCEL') . "\" />\n";
				$this->display .= "\t\t \t<input type=\"hidden\" name=\"edit_mode\" value=\"user_edit\" />\n";
				$this->display .= "\t\t </td>\n";
				$this->display .= "\t\t</tr>\n";
			}

			$this->display .= "\t</table></form>\n";
			$this->display .= '</div>' . "\n";

		}

		//-----------------------------------------------
		//--- METHOD: setEditTopicsDisplay
		//--- PURPOSE: set topic edit output display
		//--- PARAMETERS: topic id
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------

		function setEditTopicsDisplay($tid)
		{
			$this->setTopics();

			//--- Set Headers
			if (defined('TOP_HEADER')) {
				$this->accessory_display .= '<div id="PbTopHeader" class="pb_nav-bar">';
				$this->accessory_display .= TOP_HEADER;
				$this->accessory_display .= '</div>';
			}
			$this->accessory_display .= '<div id="PbSubHeader" class="pb_sh_h1">';
			$this->accessory_display .= $this->langObj->get('PB_TOPIC_ADMIN');
			$this->accessory_display .= '</div>';

			//--- Set Display
			$this->display = '<div class="pb_edit">';
			$this->display .= '<form action="' . BASE_URL . '" method="post">' . "\n";

			if ($tid) {
				//--- Add/Edit Topic
				$edit_mode = ($tid == -1) ? 'topic_insert' : 'topic_update';
				$topicObj = &new PbTopic($this->getDbPrefix(), $tid);
				$this->display .= "\n\t" . '<p class="pb_created"><span class="pb_input_text">' . $this->langObj->get('TOPIC') . ':</span> ';
				$this->display .= "\t\t" . '<input type="text" name="name" value="' . $topicObj->getName() . "\" />\n";
				$this->display .= "\t<br />\n";
				$this->display .= "\n\t" . '<span class="pb_input_text">' . $this->langObj->get('ICON') . ':</span>&nbsp;&nbsp;';
				$this->display .= "\t\t" . '<input type="text" name="icon" value="' . $topicObj->getIcon() . "\" />\n";
				if ($edit_mode !== 'topic_insert') {
					$this->display .= "\t<br />\n";
					$icon = $this->buildTopicIcon($topicObj->getIcon(), $topicObj->getName());
					$this->display .= "\t\t&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$icon\n";
				}
				$this->display .= "\t<br /><br />\n";
				$this->display .= "\t" . '<input type="submit" name="edit" value="' . $this->langObj->get('SAVE_TOPIC') . "\" />\n";
				if ($edit_mode !== 'topic_insert') {
					$this->display .= "\t" . '<input type="submit" name="topic_delete" value="' . $this->langObj->get('DELETE_TOPIC') . "\" onclick=\"return confirm('" . $this->langObj->get('CONFIRM_DELETE_TOPIC') . "')\" />\n";
				}
				$this->display .= "\t\t \t" . '<input type="submit" name="cancel" value="' . $this->langObj->get('CANCEL') . "\" />\n";
				$this->display .= "\t<input type=\"hidden\" name=\"tid\" value=\"$tid\" />\n";
				$this->display .= "\t<input type=\"hidden\" name=\"edit_mode\" value=\"$edit_mode\" />\n";
				$this->display .= "\t<input type=\"hidden\" name=\"cancel_mode\" value=\"topics\" />\n";

			} else {
				//--- Topic Selector
				$this->display .= "\n\t" . '<p class="pb_created"><span class="pb_input_text">' . $this->langObj->get('TOPIC') . ':</span> ';
				$this->display .= "\t\t<select name=\"tid\">\n";
				$this->display .= "\t\t" . ' <option value="-1">' . $this->langObj->get('OPTION_NEW_TOPIC') . "</option>\n";
				if (isset($this->topics) && count($this->topics) > 0) {
					foreach ($this->topics as $id => $obj) {
						$this->display .= "\t\t <option value=\"$id\">" . $obj->getName() . "</option>\n";
					}
				}
				$this->display .= "\t\t</select>\n";
				$this->display .= "\t<br /><br />\n";
				$this->display .= "\t" . '<input type="submit" name="edit" value="'. $this->langObj->get('EDIT_TOPIC') . "\" />\n";
				$this->display .= "\t\t \t" . '<input type="submit" name="cancel" value="' . $this->langObj->get('CANCEL') . "\" />\n";
				$this->display .= "\t<input type=\"hidden\" name=\"edit_mode\" value=\"topic_edit\" />\n";
			}

			$this->display .= "\t</p></form>\n";
			$this->display .= '</div>' . "\n";

		}

		//-----------------------------------------------
		//--- METHOD: setAddCommentDisplay
		//--- PURPOSE: set add/reply comment display
		//--- PARAMETERS: entry id
		//---					parent id
		//---					comment id (optional)
		//---					reply mode (optional)
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------

		function setAddCommentDisplay($eid, $pid, $cid = '', $reply_mode = FALSE)
		{
			//--- Setup
			$base_url = BASE_URL;
			$comment = '';
			$comment_rows = COMMENT_ROWS;
			$comment_cols = COMMENT_COLS;
			$comment_tags = str_replace('<', '&lt;', COMMENT_TAGS);
			$comment_tags = str_replace('>', '&gt;', $comment_tags);
			$edit_mode = (empty($cid)) ? 'comment_insert' : 'comment_update';
			$speller = '';
			if (defined('USE_SPELLER') && USE_SPELLER) {
				$speller = '<input type="button" name="spell_check" value="Check Spelling" onClick="openSpellChecker();" />';
			}
			$name = '';
			$email = '';
			$url = '';
			if (isset($_COOKIE['pb_comment'])) {
				$name = $_COOKIE['pb_comment']['name'];
				$email = $_COOKIE['pb_comment']['email'];
				$url = $_COOKIE['pb_comment']['url'];
			}


			//--- Set Display
			$header = $this->langObj->get('COMMENT');
			if ($reply_mode) {
				$header = $this->langObj->get('REPLY');
				$entryObj = &new PbEntry($this->getDbPrefix(), $eid);
				$commentObj = $entryObj->getComment($pid);
				$this->display .= $this->buildComment($eid, &$commentObj, FALSE);
			}
			$name_txt = $this->langObj->get('NAME');
			$email_txt = $this->langObj->get('EMAIL');
			$website_txt = $this->langObj->get('WEBSITE');
			$comment_txt = $this->langObj->get('COMMENT');
			$allowed_tags = $this->langObj->get('ALLOWED_TAGS');
			$auto_break = $this->langObj->get('AUTO_BREAK');
			$required = $this->langObj->get('REQUIRED');
			$notification = $this->langObj->get('NOTIFICATION_ONLY');
			$optional = $this->langObj->get('OPTIONAL');
			$remember = $this->langObj->get('REMEMBER_ME');
			$cancel = $this->langObj->get('CANCEL');
			$submit = $this->langObj->get('SUBMIT');
			$this->display .= <<<REPLY
				<a name="comment"></a>
				<a name="reply"></a>
				<div class="pb_sh_h1">$header</div>
				<div class="pb_edit">
				<form action="$base_url" method="post">
				<table>
					<tr>
						<td class="pb_input_text">$name_txt:</td>
						<td><input type="text" name="name" value="$name" /> ($required)</td>
					</tr>
					<tr>
						<td class="pb_input_text">$email_txt:</td>
						<td><input type="text" name="email" value="$email" /> ($notification)</td>
					</tr>
					<tr>
						<td class="pb_input_text">$website_txt:</td>
						<td><input type="text" name="url" value="$url" /> ($optional)</td>
					</tr>
					<tr>
						<td class="pb_input_text" colspan="2"><input type="checkbox" name="remember_me" value="1" checked="checked" /> $remember</td>
					</tr>
					<tr>
						<td class="pb_input_text">$comment_txt:</td>
						<td>&nbsp;</td>
					</tr>
				</table>
				<p>
					<textarea name="comment" rows="$comment_rows" cols="$comment_cols">$comment</textarea>
					<br />
					<span class="pb_input_text">$allowed_tags:</span> $comment_tags
					<br />
					&nbsp;&nbsp;<input type="checkbox" name="linebreak" value="1" checked="checked" /><span class="pb_input_text">$auto_break</span>
					<br />
					&nbsp;&nbsp;<input type="submit" name="edit" value="$submit" onclick="return ValidateComment(this.form);" />
					$speller
					<input type="submit" name="cancel" value="$cancel" />
					<input type="hidden" name="eid" value="$eid" />
					<input type="hidden" name="pid" value="$pid" />
					<input type="hidden" name="cid" value="$cid" />
					<input type="hidden" name="edit_mode" value="$edit_mode" />
				</p>
			</form>
			</div>
REPLY;

		}

		//-----------------------------------------------
		//--- METHOD: setEditCommentDisplay
		//--- PURPOSE: set edit comment display
		//--- PARAMETERS: comment object reference
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------

		function setEditCommentDisplay(&$commentObj)
		{
			//--- Setup
			$base_url = BASE_URL;
			$comment_rows = COMMENT_ROWS;
			$comment_cols = COMMENT_COLS;
			$comment_tags = str_replace('<', '&lt;', COMMENT_TAGS);
			$comment_tags = str_replace('>', '&gt;', $comment_tags);
			$speller = '';
			if (defined('USE_SPELLER') && USE_SPELLER) {
				$speller = '<input type="button" name="spell_check" value="Check Spelling" onClick="openSpellChecker();" />';
			}
			$name = $commentObj->getName();
			$email = $commentObj->getEmail();
			$url = $commentObj->getUrl();
			$cid = $commentObj->getId();
			$eid = $commentObj->getEid();
			$pid = $commentObj->getPid();
			$comment = $commentObj->getComment();
			if ($commentObj->getDisplay()) {
				$display_comment = ' checked="checked"';
			} else {
				$display_comment = '';
			}

			//--- Set Display
			$header = $this->langObj->get('EDIT_COMMENT');
			$name_txt = $this->langObj->get('NAME');
			$email_txt = $this->langObj->get('EMAIL');
			$website_txt = $this->langObj->get('WEBSITE');
			$comment_txt = $this->langObj->get('COMMENT');
			$allowed_tags = $this->langObj->get('ALLOWED_TAGS');
			$auto_break = $this->langObj->get('AUTO_BREAK');
			$required = $this->langObj->get('REQUIRED');
			$notification = $this->langObj->get('NOTIFICATION_ONLY');
			$optional = $this->langObj->get('OPTIONAL');
			$cancel = $this->langObj->get('CANCEL');
			$submit = $this->langObj->get('SUBMIT');
			$this->display .= <<<REPLY
				<a name="comment"></a>
				<div class="pb_sh_h1"></div>
				<div class="pb_edit">
				<form action="$base_url" method="post">
				<table>
					<tr>
						<td class="pb_input_text">$name_txt:</td>
						<td><input type="text" name="name" value="$name" /> ($required)</td>
					</tr>
					<tr>
						<td class="pb_input_text">$email_txt:</td>
						<td><input type="text" name="email" value="$email" /> ($notification)</td>
					</tr>
					<tr>
						<td class="pb_input_text">$website_txt:</td>
						<td><input type="text" name="url" value="$url" /> ($optional)</td>
					</tr>
					<tr>
						<td class="pb_input_text">$comment_txt:</td>
						<td>&nbsp;</td>
					</tr>
				</table>
				<p>
					<textarea name="comment" rows="$comment_rows" cols="$comment_cols">$comment</textarea>
					<br />
					<span class="pb_input_text">$allowed_tags:</span> $comment_tags
					<br />
					&nbsp;&nbsp;<input type="checkbox" name="linebreak" value="1" checked="checked" /><span class="pb_input_text">$auto_break</span>
					&nbsp;&nbsp;<input type="checkbox" name="display" value="1"$display_comment /><span class="pb_input_text">Display Entry</span>
					<br />
					&nbsp;&nbsp;<input type="submit" name="edit" value="$submit" onclick="return ValidateComment(this.form);" />
					$speller
					<input type="submit" name="cancel" value="$cancel" />
					<input type="hidden" name="eid" value="$eid" />
					<input type="hidden" name="pid" value="$pid" />
					<input type="hidden" name="cid" value="$cid" />
					<input type="hidden" name="edit_mode" value="comment_update" />
				</p>
			</form>
			</div>
REPLY;

		}

		//-----------------------------------------------
		//--- METHOD: setEntries
		//--- PURPOSE: set entries in object
		//--- PARAMETERS: start id or date
		//---					is date flag
		//---					topic id
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setEntries($start = NULL, $is_date = FALSE, $tid = FALSE)
		{

			//--- Set Total Entry Count
			$this->setEntryCnt();

			//--- Query - This Date
			if ($is_date) {
				$display_flag = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? " AND display='1'" : '';
				$post_dated = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? ' AND updated<=UNIX_TIMESTAMP()' : '';
				$query = "SELECT
								eid
							 FROM
						 		{$this->prefix}entries
						 	 WHERE
						 	 	DATE_FORMAT(FROM_UNIXTIME(updated), '%Y%m%d')='%s'
						 	 $display_flag
						 	 $post_dated
						 	 ORDER BY
						 	 	updated";
				$query_data = array($start);
			} else {
				//--- Query - Start Position
				$where = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? "WHERE display='1'" : '';
				$where .= ($tid && (isset($_SESSION['login']) && $_SESSION['login'])) ? "WHERE tid='$tid'" : '';
				$where .= ($tid && !(isset($_SESSION['login']) && $_SESSION['login'])) ? " AND tid='$tid'" : '';
				$where .= (!(isset($_SESSION['login']) && $_SESSION['login'])) ? ' AND updated<=UNIX_TIMESTAMP()' : '';
				$limit = ($start) ? 'LIMIT ' . $start . ',' . $this->display_cnt : 'LIMIT ' . $this->display_cnt;
				$query = "SELECT
								eid
							 FROM
						 		{$this->prefix}entries
						 	$where
						 	 ORDER BY
						 	 	updated
						 	 DESC
						 	 $limit";
				$query_data = array();
			}

			//--- Issue Query
			if ($this->dbObj->safeQuery($query, $query_data)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {

					//--- Retrieve Results
					$i = 0;
					while ($this->dbObj->getRow()) {
						$eid = (int) $this->dbObj->row['eid'];
						$this->entries[$i] = &new PbEntry($this->getDbPrefix(), $eid);
						$i++;
					}

				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setUsers
		//--- PURPOSE: set users in object
		//--- PARAMETERS: none
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setUsers()
		{
			//--- Reset
			unset($this->users);

			//--- Query
			$query = "SELECT
							id
						 FROM
					 		{$this->prefix}users
					 	 ORDER BY
					 	 	user";

			//--- Issue Query
			if ($this->dbObj->query($query)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {

					//--- Retrieve Results
					while ($this->dbObj->getRow()) {
						$id = (int) $this->dbObj->row['id'];
						$this->users[$id] = &new PbUser($this->getDbPrefix(), $id);
					}
				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setTopics
		//--- PURPOSE: set topics in object
		//--- PARAMETERS: none
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setTopics()
		{
			//--- Reset
			unset($this->topics);

			//--- Query
			$query = "SELECT
							tid
						 FROM
					 		{$this->prefix}topics
					 	 ORDER BY
					 	 	name";

			//--- Issue Query
			if ($this->dbObj->query($query)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {

					//--- Retrieve Results
					while ($this->dbObj->getRow()) {
						$tid = (int) $this->dbObj->row['tid'];
						$this->topics[$tid] = &new PbTopic($this->getDbPrefix(), $tid);
					}
				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setFailDisplay
		//--- PURPOSE: set message posting failure display
		//--- PARAMETERS: none
		//--- RETURNS: XHTML display data
		//-----------------------------------------------
		function setFailDisplay($msg = '')
		{
			$this->fail_display = '<div class="pb_entry">';
			$this->fail_display .= '<p class="pb_body">' . $this->langObj->get('FAIL_DISPLAY_MSG') . ':<br /><br />';
			$this->fail_display .= '<span class="pb_search_fail">' . htmlentities(stripslashes($msg)) . '</span>';
			$this->fail_display .= '<br /><br />' . $this->langObj->get('TRY_AGAIN') . '</p>';
			$this->fail_display .= '</div>';
		}

		//-----------------------------------------------
		//--- METHOD: setEntryCnt
		//--- PURPOSE: set total entry count in object
		//--- PARAMETERS: none
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function setEntryCnt()
		{

			//--- Query
			$display_flag = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? "WHERE display='1'" : '';
			$post_dated = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? ' AND updated<=UNIX_TIMESTAMP()' : '';
			$query = "SELECT
							COUNT(*) AS count
						 FROM
					 		{$this->prefix}entries
					 	 $display_flag
					 	 $post_dated";

			//--- Issue Query
			if ($this->dbObj->query($query)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {

					//--- Retrieve Results
					$this->dbObj->getRow();
					$this->entry_cnt = (int) $this->dbObj->row['count'];

				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			return $stat;
		}

		//-----------------------------------------------
		//--- METHOD: setLoginDisplay
		//--- PURPOSE: sets login display screen
		//--- PARAMETERS: username (optional)
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setLoginDisplay($username)
		{
			$this->display = '<div class="pb_entry">' . "\n";
			$this->display .= '<form action="' . BASE_URL . '" method="post">' . "\n";
			$this->display .= '<table>' . "\n";
			$this->display .= "\t<tr>\n";
			$this->display .= "\t\t" . '<th align="right">' . $this->langObj->get('USERNAME') . ":</th>\n";
			$this->display .= "\t\t<td><input type=\"text\" name=\"user\" value=\"$username\" /></td>\n";
			$this->display .= "\t</tr>\n";
			$this->display .= "\t<tr>\n";
			$this->display .= "\t" . '<th align="right">' . $this->langObj->get('PASSWORD') . ":</th>\n";
			$this->display .= "\t<td><input type=\"password\" name=\"passwd\" value=\"\" /></td>\n";
			$this->display .= "\t</tr>\n";
			$this->display .= "\t<tr>\n";
			$this->display .= '<td>&nbsp;</td>' . "\n";
			$this->display .= "\t</tr>\n";
			$this->display .= "\t<tr>\n";
			$this->display .= "\t\t" . '<td><input type="submit" name="login_req" value="' . $this->langObj->get('LOGIN') . '" /></td>' ."\n";
			$this->display .= "\t</tr>\n";
			$this->display .= '</table>' . "\n";
			$this->display .= '<form>' . "\n";
			$this->display .= '</div>' . "\n";
		}

		//-----------------------------------------------
		//--- METHOD: setEntry
		//--- PURPOSE: add/edit entry
		//--- PARAMETERS: add/edit mode
		//---					entry id
		//---					entry title
		//---					entry topic id
		//---					entry add linebreaks?
		//---					entry display?
		//---					allow comments?
		//---					entry body text
		//---					entry more text
		//---					entry update timestamp
		//---					entry time adjust direction
		//---					entry time adjust hours
		//---					entry time adjust minutes
		//---					ping Ping-O-Matic!
		//--- RETURNS: nothing
		//-----------------------------------------------
		function setEntry($mode, $eid, $title, $tid, $linebreak, $display, $allow_comments, $body, $more, $update_timestamp, $create_timestamp, $time_adj_dir, $time_adj_hour, $time_adj_min, $ping = FALSE)
		{
			//--- Build Entry Object
			$this->entries[0] = &new PbEntry($this->getDbPrefix(), $eid);
			$this->entries[0]->setId($eid);
			$this->entries[0]->setTitle($title);
			$this->entries[0]->setTopicId($tid);
			$this->entries[0]->setLineBreak($linebreak);
			$this->entries[0]->setDisplay($display);
			$this->entries[0]->setAllowComments($allow_comments);
			$this->entries[0]->setBody($body);
			$this->entries[0]->setMore($more);
			$this->entries[0]->setAdjustTime($update_timestamp, $create_timestamp, $time_adj_dir, $time_adj_hour, $time_adj_min);
			$this->entries[0]->setPing($ping);

			//--- Add Entry
			if ($mode === 'insert') {
				$stat = $this->entries[0]->insertEntry();
			} elseif($mode === 'update') {
				//--- Update Entry
				$stat = $this->entries[0]->updateEntry();
			}

			//--- Query Error
			if (!$stat) {
				$this->setFailDisplay($this->entries[0]->dbObj->getError());
			}

			return $stat;
		}






		//-----------------------------------------------
		//-----------------------------------------------
		//--- GET METHODS -------------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: getCommentIndent
		//--- PURPOSE: get comment indent value
		//--- PARAMETERS: none
		//--- RETURNS: comment indent value
		//-----------------------------------------------
		function getCommentIndent()
		{
			return $this->comment_indent;
		}

		//-----------------------------------------------
		//--- METHOD: getDisplay
		//--- PURPOSE: get display output
		//--- PARAMETERS: none
		//--- RETURNS: XHTML display data
		//-----------------------------------------------
		function getDisplay()
		{
			return $this->display;
		}

		//-----------------------------------------------
		//--- METHOD: getAccessoryDisplay
		//--- PURPOSE: get calendar & header display output
		//--- PARAMETERS: none
		//--- RETURNS: XHTML calendar display data
		//-----------------------------------------------
		function getAccessoryDisplay()
		{
			return $this->accessory_display;
		}

		//-----------------------------------------------
		//--- METHOD: getFailDisplay
		//--- PURPOSE: get query fail display output
		//--- PARAMETERS: none
		//--- RETURNS: XHTML error display data
		//-----------------------------------------------
		function getFailDisplay()
		{
			return $this->fail_display;
		}

		//-----------------------------------------------
		//--- METHOD: getEntryCnt
		//--- PURPOSE: get total entry count
		//--- PARAMETERS: none
		//--- RETURNS: (int) entry count
		//-----------------------------------------------
		function getEntryCnt()
		{
			return $this->entry_cnt;
		}

		//-----------------------------------------------
		//--- METHOD: getWordCnt
		//--- PURPOSE: get string word count
		//--- PARAMETERS: (string) text string
		//--- RETURNS: (int) word count in string
		//-----------------------------------------------
		function getWordCnt($str)
		{
			$str = trim(strip_tags($str));
			$word_cnt = (strlen($str) == 0) ? 0 : count(explode(' ', $str));
/*			if (version_compare(phpversion(), '4.3.0', '>')) {
				$word_cnt = str_word_count($str, 1);
			} else {
				$word_cnt = count(explode(' ', $str));
			}
*/

			return $word_cnt;
		}




		//-----------------------------------------------
		//-----------------------------------------------
		//--- OTHER METHODS -----------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: buildEntry
		//--- PURPOSE: build entry div content
		//--- PARAMETERS: entry object reference
		//---					full entry display flag
		//---					comment mode flag (optional)
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildEntry(&$entryObj, $full_entry = FALSE, $footer_enabled = TRUE)
		{

			$tid = $entryObj->getTopicId();
			$content = '';

			//--- Date Separator
			if ((defined('DATE_SEPARATOR_FORMAT') || defined('I18N_DATE_SEPARATOR_FORMAT')) && $this->getEntryCnt() > 1) {
				$content .= $this->buildDateSeparator($entryObj->getUpdated());
			}

			//--- Header
			$content .= '<div class="pb_entry">' . "\n";
			$content .= "\t<div class=\"pb_topic_icon\">\n";
			$content .= "\t " . $this->buildTopicLink($tid) . "\n";
			$content .= "\t " . '&nbsp;&nbsp;<span class="pb_title">' . $entryObj->getTitle() . '</span>';
			$content .= (!$entryObj->getDisplay()) ? ' (<span style="color:#d50000; font-size:14px; font-weight:bold;">' . $this->langObj->get('DISPLAY_DISABLED') . '</span>)<br />'  ."\n" : '<br />'  ."\n";
			$content .= "\t " . '<span class="pb_created">' . $entryObj->getCreated(TRUE) . "</span>\n";
			if ($entryObj->getCreated() != $entryObj->getUpdated()) {
				$content .= "\t <br />\n";
				$content .= "\t " . '<span class="pb_created">' . $this->langObj->get('UPDATED') . ': ' . $entryObj->getUpdated(TRUE) . "</span>\n";
			}
			if (defined('USE_POST_BY') && USE_POST_BY) {
				$content .= "\t <br />\n";
				$content .= "\t " . '<span class="pb_created">' . $this->langObj->get('POSTED_BY') . ' ' . $entryObj->getPostBy() . "</span>\n";
			}
			$content .= "\t</div>\n";

			//--- Main Entry Content
			if (defined('USE_GIGGLE') && USE_GIGGLE) {
				$content .= "\t" . '<div class="pb_body">' . "\n" . $entryObj->getBody('GIGGLE') . "\n";
			} else {
				$content .= "\t" . '<div class="pb_body">' . "\n" . $entryObj->getBody() . "\n";
			}

			//--- More Link
			if (!$full_entry && $entryObj->getMoreExists()) {
				$content .= '&nbsp;&nbsp;';
				$content .= $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId(), $this->langObj->get('READ_MORE_OF') . ' ' . $entryObj->getTitle(), $this->langObj->get('READ_MORE') . '&hellip;') . "\n";
			} elseif ($full_entry && $entryObj->getMoreExists()) {
				//--- Include Full Entry
				$content .= '<br /><br />';
				if (defined('USE_GIGGLE') && USE_GIGGLE) {
					$content .= $entryObj->getMore('GIGGLE');
				} else {
					$content .= $entryObj->getMore();
				}

			}

			$content .= "\t</div>\n";

			if ($footer_enabled) {
				//--- Footer Links
				$link = $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId(), $this->langObj->get('PERMALINK') . ': ' . $entryObj->getTitle(), $this->langObj->get('PERMALINK'));
				$content .= "\t<span class=\"pb_entry_footer\">\n";
				$content .= "\t [$link]\n";

				//--- Comment Links
				if (defined('USE_COMMENTS') && USE_COMMENTS) {
					if ($entryObj->getAllowComments()) {
						if ($entryObj->getCommentCnt() > 0) {
							$link = $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId() . '#comments', $this->langObj->get('COMMENT_VIEW') . ' ' . $entryObj->getTitle(), $this->langObj->get('COMMENTS') . '  (' . $entryObj->getCommentCnt() . ')');
							$content .= "\t&nbsp;&nbsp;[$link]\n";
						}
						if (!$this->getIpBlocked($this->getUserIp())) {
							$link = $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId() . '&amp;pid=0#comment', $this->langObj->get('COMMENT_ON') . ' ' . $entryObj->getTitle(), $this->langObj->get('COMMENT_ADD'));
							$content .= "\t&nbsp;&nbsp;[$link]\n";
						}
					} else {
						$link = $this->langObj->get('COMMENTS_DISABLED') . ' (' . $entryObj->getCommentCnt() . ')';
						$content .= "\t&nbsp;&nbsp;[$link]\n";
					}
				}

				//--- Google Link
				if (defined('USE_GOOGLE_LINK') && USE_GOOGLE_LINK) {
					$google_topic = htmlentities(urlencode($entryObj->getTitle()));
					$google = $this->buildLink('http://www.google.com/search?q=' . $google_topic, $this->langObj->get('GOOGLE_FOR') . ': ' . $entryObj->getTitle(), $this->langObj->get('GOOGLE'));
					$content .= "\t&nbsp;&nbsp;[$google]\n";
				}

				//--- Word Count
				if (defined('USE_WORD_COUNT') && USE_WORD_COUNT) {
					$word_cnt = $this->getWordCnt($entryObj->getBody('DO_STUPEFY'));
					$word_cnt += $this->getWordCnt($entryObj->getMore('DO_STUPEFY'));
					$word_msg = ($word_cnt > 1) ? '(' . $word_cnt . ' ' . $this->langObj->get('WORDS') . ')' : '(' . $word_cnt . ' ' . $this->langObj->get('WORD') . ')';
					$word_msg = ($word_cnt == 0) ? '' : $word_msg;
					$content .= "\t&nbsp;&nbsp;$word_msg\n";
				}

				//--- Admin Links
				if ( (isset($_SESSION['login']) && $_SESSION['login']) && ( (isset($_SESSION['admin']) && $_SESSION['admin']) || (isset($_SESSION['uid']) && $_SESSION['uid'] == $entryObj->getUid()) ) ) {
					$content .= "<br />\n";
					$link = $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId() . '&admin=edit', $this->langObj->get('EDIT') . ': ' . $entryObj->getTitle(), $this->langObj->get('EDIT_ENTRY'));
					$content .= "\t&nbsp;&nbsp;&nbsp;[$link]\n";
					$url = "javascript:confirmDelete('" . BASE_URL . '?eid=' . $entryObj->getId() . '&admin=del' . "')";
					$link = $this->buildLink($url, 'Delete: ' . $entryObj->getTitle(), $this->langObj->get('DELETE_ENTRY'));
					$content .= "\t [$link]\n";
				}
				$content .= "\t</span>\n";
			}
			$content .= '</div>' . "\n";

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildComment
		//--- PURPOSE: build comment content
		//--- PARAMETERS: entry id
		//---					comment object reference
		//---					comment mode flag (optional)
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildComment($eid, &$commentObj, $footer_enabled = TRUE)
		{
			$content = '';
			$reply = '';
			$word_msg = '';
			$cid = $commentObj->getId();
			$name = $commentObj->getName();
			$url = $commentObj->getUrl();
			$timestamp = $commentObj->getTimestamp(TRUE);
			$ip = $commentObj->getIp();
			$comment = $commentObj->getComment();
			$link = $name;
			if (!empty($url)) {
				$link = $this->buildLink('http://' . $url, $this->langObj->get('WEBSITE_OF') . ' ' . $name, $name);
			}
			$permalink = $this->buildLink(BASE_URL . '?eid=' . $commentObj->getEid() . '#' . $cid, $this->langObj->get('PERMALINK_TO_COMMENT'), $this->langObj->get('PERMALINK'));
			$permalink = "[$permalink]";
			if (!$this->getIpBlocked($this->getUserIp())) {
				$reply = $this->buildLink(BASE_URL . '?eid=' . $eid . '&amp;pid=' . $commentObj->getId() . '#reply', $this->langObj->get('REPLY_TO') . ' ' . $name . $this->langObj->get('REPLY_TO_NAMES_COMMENT') . '.', $this->langObj->get('REPLY'));
				$reply = "&nbsp;&nbsp;[$reply]";
			}
			if (defined('USE_WORD_COUNT') && USE_WORD_COUNT) {
				$word_cnt = $this->getWordCnt($commentObj->getComment('DO_STUPEFY'));
				$word_msg = '&nbsp;&nbsp;';
				$word_msg .= ($word_cnt > 1) ? '(' . $word_cnt . ' ' . $this->langObj->get('WORDS') . ')' : '(' . $word_cnt . ' ' . $this->langObj->get('WORD') . ')';
				$word_msg = ($word_cnt == 0) ? '' : '&nbsp;&nbsp;' . $word_msg;
			}

			//--- Admin Links
			$admin = '';
			if ( (isset($_SESSION['login']) && $_SESSION['login']) && (isset($_SESSION['admin']) && $_SESSION['admin']) ) {
				$edit_link = $this->buildLink(BASE_URL . '?cid=' . $cid . '&admin=edit_comment', $this->langObj->get('EDIT_COMMENT_BY') . ' ' . $commentObj->getName(), $this->langObj->get('EDIT_COMMENT'));
				$url = "javascript:confirmDeleteComment('" . BASE_URL . '?cid=' . $cid . '&admin=del_comment' . "')";
				$del_link = $this->buildLink($url, $this->langObj->get('DELETE_COMMENT_BY') . ' ' . $commentObj->getName(), $this->langObj->get('DELETE_COMMENT'));
				$admin = <<<ADMIN_COMMENT
				<br />
				&nbsp;&nbsp;&nbsp;[$edit_link]
				&nbsp;&nbsp;[$del_link]
ADMIN_COMMENT;
			}

			if (((isset($_SESSION['login']) && $_SESSION['login']) && (isset($_SESSION['admin']) && $_SESSION['admin'])) || $commentObj->getDisplay()) {
				$ip_display = ((isset($_SESSION['login']) && $_SESSION['login']) && (isset($_SESSION['admin']) && $_SESSION['admin'])) ? '(' . $ip . ')' : '';

				$indent = $this->getCommentIndent();
				$comment_by = $this->langObj->get('COMMENT_BY');
				$disabled = (!$commentObj->getDisplay()) ? ' (<span style="color:#d50000; font-size:14px; font-weight:bold;">' . $this->langObj->get('DISPLAY_DISABLED') . '</span>)' : '';
				$content .= <<<COMMENT
				<div><a name="$cid"></a></div>
				<div class="pb_entry" style="margin-left: {$indent}px;">
					<span class="pb_created">$timestamp</span>
					<br />
					<span class="pb_created">$comment_by $link $ip_display $disabled</span>
					<br />
					<br />
					<div class="pb_body">$comment</div>
COMMENT;

				if ($footer_enabled) {
					$content .= <<<COMMENT_FOOTER
					<span class="pb_entry_footer">
						&nbsp;&nbsp;$permalink$reply$word_msg
						$admin
					</span>
COMMENT_FOOTER;
				}
			}
			$content .= "\t\t\t\t</div>\n";

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildComments
		//--- PURPOSE: build full block of entry comments
		//--- PARAMETERS: entry object reference
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildComments(&$entryObj)
		{
			$content = '';
			if ($entryObj->getCommentCnt() > 0) {
				$comments = $entryObj->getComments();
				$content .= $this->buildNestedComments(&$entryObj, &$comments);
			}

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildNestedComments
		//--- PURPOSE: build comments content
		//--- PARAMETERS: entry object reference
		//---					comments id array reference
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildNestedComments(&$entryObj, &$comments)
		{
			$content = '';
			$indent = COMMENT_INDENT_INCREMENT;
			if (empty($this->comment_indent)) {
				$this->setCommentIndent(COMMENT_INDENT);
			}

			foreach ($comments as $commentObj) {
				$content .= $this->buildComment($entryObj->getId(), &$commentObj);
				//--- Nested Replies
				$replies = $entryObj->getComments($entryObj->getId(), $commentObj->getId());
				$current_indent = $this->getCommentIndent();
				if (count($replies) > 0) {
					$this->setCommentIndent($this->getCommentIndent() + $indent);
					$content .= $this->buildNestedComments(&$entryObj, &$replies);
				}
				$this->setCommentIndent($current_indent);
			}

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildDateSeparator
		//--- PURPOSE: build date separator display
		//--- PARAMETERS: entry date
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildDateSeparator($date)
		{
			$content = '';
			$build = FALSE;

			//--- Date Check
			$entry_date = (defined('I18N_DATE_SEPARATOR_FORMAT')) ? strftime(I18N_DATE_SEPARATOR_FORMAT, $date) :	date(DATE_SEPARATOR_FORMAT, $date);
			if (!isset($this->separator_date)) {
				$this->separator_date = $entry_date;
				$build = TRUE;
			} elseif (isset($this->separator_date) && $this->separator_date != $entry_date) {
				$this->separator_date = $entry_date;
				$build = TRUE;
			}

			//--- Build Content
			if ($build) {
				$content = "\t" . '<div class="pb_date_separator">' . "\n";
				$content .= "\t $entry_date\n";
				$content .= "\t</div>\n";
			}

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildIndex
		//--- PURPOSE: build index display
		//--- PARAMETERS: none
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildIndex()
		{
			$date_hdr = '';
			$content = '<div class="pb_entry">' . "\n";
			foreach ($this->entries as $entryObj) {
				$topicObj = $this->topics[$entryObj->getTopicId()];
				$topic = $topicObj->getName();
				$entry_date = strftime('%B %Y', $entryObj->getUpdated());
				if ($date_hdr != $entry_date && empty($date_hdr)) {
					$date_hdr = $entry_date;
					$content .= <<< DATE_HDR_START
					<span class="pb_title">$entry_date</span>
					<br />
					<ul>
DATE_HDR_START;
				} elseif ($date_hdr != $entry_date) {
					$date_hdr = $entry_date;
					$content .= <<< DATE_HDR_CONT
					</ul>
					<br />
					<span class="pb_title">$entry_date</span>
					<br />
					<ul>
DATE_HDR_CONT;
				}
				$content .= '<li>' . $this->buildLink(BASE_URL . '?eid=' . $entryObj->getId(), $topic . ': ' . $entryObj->getTitle() . ' (' . $entryObj->getUpdated(TRUE) . ')', $entryObj->getTitle()) . '</li>' . "\n";
			}
			$content .= '</ul>' . "\n";
			$content .= '</div>' . "\n";

			return $content;
		}

		//-----------------------------------------------
		//--- METHOD: buildTopicLink
		//--- PURPOSE: build entry topic header
		//--- PARAMETERS: topic Id
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildTopicLink($tid)
		{
			$icon = $this->buildTopicIcon($this->topics[$tid]->getIcon(), $this->topics[$tid]->getName());
			return $this->buildLink(BASE_URL . '?tid=' . $tid, $this->langObj->get('TOPIC') . ': ' . $this->topics[$tid]->getName(), $icon);
		}

		//-----------------------------------------------
		//--- METHOD: buildTopicIcon
		//--- PURPOSE: build a topic icon image tag
		//--- PARAMETERS: topic src
		//--- 				topic alt
		//--- RETURNS: XHTML hyperlink
		//-----------------------------------------------
		function buildTopicIcon($src, $topic)
		{
			$topic_size = '';
			if (defined('TOPIC_ICON_WIDTH') && defined('TOPIC_ICON_HEIGHT')) {
				$topic_size =  ' width="' . TOPIC_ICON_WIDTH . '" height="' . TOPIC_ICON_HEIGHT .'"';
			}
			return '<img class="pb_no_border" src="' . $src . '" alt="' . $this->langObj->get('TOPIC') . ': ' . $topic . '"' . $topic_size . ' />';
		}

		//-----------------------------------------------
		//--- METHOD: buildNavBar
		//--- PURPOSE: build the navigation bar
		//--- PARAMETERS: display start position
		//--- 				search string
		//--- 				topic id
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		function buildNavBar($start, $search, $tid = FALSE)
		{
			$param = ($this->index_mode) ? 'index' : 'start';

			$nav_bar = '<div class="pb_content">' . "\n";
			$nav_bar .= "\t<table>\n";
			$nav_bar .= "\t\t<tr>\n";
			$nav_bar .= "\t\t <td colspan=\"3\">\n";
			$nav_bar .= "\t\t <form action=\"" . BASE_URL . "\" method=\"post\">\n";
			$nav_bar .= "\t\t <p>" . $this->langObj->get('TOPIC') . ":\n";
			$nav_bar .= "\t\t <select name=\"tid\">\n";
			$nav_bar .= "\t\t" . '  <option value="-1">' . $this->langObj->get('ALL') . "</option>\n";
			if (isset($this->topics) && count($this->topics) > 0) {
				foreach ($this->topics as $topic) {
					$nav_bar .= "\t\t  <option value=\"" . $topic->getID() . '">' . $topic->getName() . "</option>\n";
				}
			}
			$nav_bar .= "\t\t </select>\n";
			$search = htmlentities(stripslashes($search));
			$nav_bar .= "\t\t <input type=\"text\" name=\"search\" value=\"{$search}\" />\n";
			$nav_bar .= "\t\t " . '&nbsp;<input type="submit" name="search_btn" value="' . $this->langObj->get('SEARCH') . '" />' . "\n";
			$nav_bar .= "\t\t </p></form>\n";
			$nav_bar .= "\t\t </td>\n";
			$nav_bar .= "\t\t</tr>\n";
			$nav_bar .= "\t\t<tr>\n";
			$nav_bar .= "\t\t <th class=\"pb_align_left\">\n";

			if ($start > 0) {
				$prev_start = $start - $this->display_cnt;
				$nav_bar .= "\t\t  <a href=\"" . BASE_URL . "?$param=$prev_start";
				$nav_bar .= ($tid) ? "&amp;tid=$tid\">" : '">';
				$nav_bar .= '<img class="pb_no_border" src="' . PREV_ICON . '" alt="' . $this->langObj->get('PREV_ENTRIES') . '" width="16" height="16" />';
				$nav_bar .= (PREV_TEXT) ? '&nbsp;' . $this->langObj->get('PREVIOUS') . '&nbsp;' : '';
				$nav_bar .= '</a>';
			} else {
				$nav_bar .= "<img src=\"gfx/blank.png\" alt=\"\" width=\"16\" height=\"16\" />";
			}
			$nav_bar .= "\n\t\t </th>";
			$nav_bar .= "\n\t\t <th>";
			$nav_bar .= "\t\t <form action=\"" . BASE_URL . "\" method=\"get\">\n";
			$nav_bar .= '<p>&nbsp;<input type="submit" name="recent" value="' . $this->langObj->get('DISPLAY_RECENT_ENTRIES') . '" />' . "\n";
			$nav_bar .= "\t\t </p></form>\n";
			$nav_bar .= "\n\t\t </th>";
			$nav_bar .= "\t\t <th class=\"pb_align_right\">\n";

			if (empty($search) && $start <= $this->getEntryCnt() && $start + $this->display_cnt <= $this->getEntryCnt()) {
				$next_start = $start + $this->display_cnt;
				$nav_bar .= "\t\t  <a href=\"" . BASE_URL . "?$param=$next_start";
				$nav_bar .= ($tid) ? "&amp;tid=$tid\">" : '">';
				$nav_bar .= (NEXT_TEXT) ? '&nbsp;' . $this->langObj->get('NEXT') . '&nbsp;' : '';
				$nav_bar .= '<img class="pb_no_border" src="' . NEXT_ICON . '" alt="' . $this->langObj->get('NEXT_ENTRIES') . '" width="16" height="16" />';
				$nav_bar .= '</a>';
			} else {
				$nav_bar .= (NEXT_TEXT) ? '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;' : '';
			}
			$nav_bar .= "\n\t\t </th>\n";
			$nav_bar .= "\t\t</tr>\n";
			$nav_bar .= "\t</table>\n";
			$nav_bar .= "</div>\n";

			return $nav_bar;
		}

		//-----------------------------------------------
		//--- METHOD: searchEntries
		//--- PURPOSE: set entry ID that match search criteria
		//--- PARAMETERS: topic ID
		//--- PARAMETERS: search text
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function searchEntries($tid, $search)
		{
			$search = htmlentities($search);
			$display_flag = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? "AND display='1'" : '';
			$post_dated = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? ' AND updated<=UNIX_TIMESTAMP()' : '';
			$boolean_search = (defined('BOOLEAN_SEARCH') && BOOLEAN_SEARCH) ? ' IN BOOLEAN MODE' : '';
			$query = "SELECT
							eid
						 FROM
						 	{$this->prefix}entries
						 WHERE
						 	MATCH (title,body,more)
						 	AGAINST ('{$search}'{$boolean_search})
						 $display_flag
						 $post_dated
						 ORDER BY created DESC";

			//--- Search within Topic
			if ($tid !== FALSE) {
				$query .= " AND tid={$tid}";
			}

			//--- Issue Query
			if ($this->dbObj->query($query)) {

				//--- Check for results
				if ($this->dbObj->result_cnt > 0) {
					$this->entry_cnt = (int) $this->dbObj->result_cnt;

					//--- Retrieve Results
					$i = 0;
					while ($this->dbObj->getRow()) {
						$eid = (int) $this->dbObj->row['eid'];
						$this->entries[$i] = &new PbEntry($this->getDbPrefix(), $eid);
						$i++;
					}
				}

				$stat = TRUE;

			} else {

				//--- Query Error
				echo $this->dbObj->getError();
				$stat = FALSE;
			}

			return $stat;
		}




		//-----------------------------------------------
		//-----------------------------------------------
		//--- Calendar Methods --------------------------
		//-----------------------------------------------
		//-----------------------------------------------


		//-----------------------------------------------
		//--- METHOD: buildCalendar
		//--- PURPOSE: build calendar display
		//--- PARAMETERS: month (optional)
		//---					year (optional)
		//--- RETURNS: XHTML content
		//-----------------------------------------------
		/*
			This function is started life as mk_drawCalendar(),
			part of the Simplog weblog program by
			Jeremy Ashcraft (f-bomb) <ashcraft@13monkeys.com>
			http://www.simplog.org

			It was largely rewritten (by me) for use in Personal
			Weblog by Mark Pulford <mark@kyne.com.au>
			http://www.kyne.com.au/~mark/

			It now begins its third life here in PolarBlog
			with some bug fixes and DB access rework.
			Kevin L.	Papendick <kevinp@polarlava.com>
			http://www.polarlava.com
		*/
		function buildCalendar($m = 'now', $y = 'now')
		{

		   //--- Untaint
		   $m = preg_match('/^\d{1,2}$/', $m) ? (int) $m : 'now';
		   $y = preg_match('/^\d{1,4}$/', $y) ? (int) $y : 'now';
		   $now = ($m === 'now' && $y === 'now') ? TRUE : FALSE;

			//--- Set current month if not specified
			if ($m == 'now') {
				$m = date('n', mktime());
			}

			//--- Set current year if not specified
			if ($y == 'now') {
				$y = date('Y', mktime());
			}

			//--- Find weekday the first is on
			$timestamp = mktime(0,0,0,$m,1,$y);
			$tmpd = getdate($timestamp);
			$month = strftime('%B', $timestamp);
			$firstwday= $tmpd["wday"];
			$today = date("Ymd",mktime());
			$lastday = $this->get_last_month_day($m,$y);

			$dayAbbrevs = array();
			$timestamp = mktime(12, 0, 0, 1, 4, 1970); // get a timestamp from a Sunday
			for ($i = 0; $i < 7; $i++) {
				$dayAbbrevs[$i] = strftime('%a', $timestamp);
				$timestamp += 86400; // Add another day
			}

			$output = <<<CAL_HDR
			<table class="pb_cal_style" width="100%">
			 <tr>
			  <th colspan="7">$month $y</th>
			 </tr>
			 <tr>
			  <td>$dayAbbrevs[0]</td>
			  <td>$dayAbbrevs[1]</td>
			  <td>$dayAbbrevs[2]</td>
			  <td>$dayAbbrevs[3]</td>
			  <td>$dayAbbrevs[4]</td>
			  <td>$dayAbbrevs[5]</td>
			  <td>$dayAbbrevs[6]</td>
			 </tr>

CAL_HDR;

			$d = 1;
			$wday = $firstwday;
			$firstweek = TRUE;

			 //--- Loop through days and build required links
			 while ($d <= $lastday) {

			    //--- Set up blank days for first week
			    if ($firstweek && $firstwday != 0) {
			    	$output .= "\n<tr>\n";
			    	for ($i = 1; $i <= $firstwday; $i++) {
			    		$output .= "\t\t  <td>&nbsp;</td>\n";
			    	}
			    	$firstweek = FALSE;
			    }

	   	    //--- Sunday starts the week/table row
	   	    if ($wday == 0) { $output .= "\t\t <tr>\n"; }


	   	    $m_formatted = sprintf("%02d", $m);
	   	    $d_formatted = sprintf("%02d", $d);

	 			//--- Look for blog entries on this day
	 			$start_day = mktime(0,0,0,$m,$d,$y);
	 			$end_day = mktime(23,59,59,$m,$d,$y);
				$display_flag = (!(isset($_SESSION['login']) && $_SESSION['login'])) ? "AND display='1'" : '';
				$post_dated = (!(isset($_SESSION['login']) && $_SESSION['login']) && $now) ? ' AND updated<=UNIX_TIMESTAMP()' : '';
			   $query = "SELECT
			   				COUNT(*) count
			   			 FROM
			   			 	{$this->prefix}entries
			   			 WHERE
			   			 	(updated >= $start_day
			   			 		AND
			   			 	updated <= $end_day)
			   			 $display_flag
			   			 $post_dated";

				//--- Issue Query
				if ($this->dbObj->query($query)) {

					//--- Check for results
					if ($this->dbObj->result_cnt > 0) {

						//--- Retrieve Results
						$this->dbObj->getRow();
						$count = (int) $this->dbObj->row['count'];

					}

					$stat = TRUE;

				} else {

					//--- Query Error
					echo $this->dbObj->getError();
					$stat = FALSE;
				}

				//--- check for event
	   	   $showdate = $y.$m_formatted.$d_formatted;
	   	   $link_style = ($showdate == $today) ? 'pb_cal_link_today' : 'pb_cal_link';

				//--- Entries on that days entries
				if($count > 0) {
					$entry_cnt = ($count > 1) ? $count . ' ' . $this->langObj->get('ENTRIES') : $count . ' ' . $this->langObj->get('ENTRY');
					$output .= "\t\t  " . '<td class="' . $link_style . '"><a href="' . BASE_URL . '?date=' . $y . $m_formatted . $d_formatted . '&amp;m=' . $m_formatted . '&amp;y=' . $y . '" title="'. $entry_cnt . '">' . $d . "</a></td>\n";
				} elseif($showdate == $today) {
					$output .= "\t\t  " . '<td class="pb_cal_today">' . $d . "</td>\n";
				} else {
					$output .= "\t\t  " . '<td>' . $d . "</td>\n";
				}

				//--- Saturday ends the week/table row
	   	   if ($wday==6) { $output .= "\t\t </tr>\n"; }

				//--- Loop Reset
				$wday++;
	   	   $wday = $wday % 7;
	   	   $d++;
			}

			if($wday != 0) {
				for ($i=$wday; $i < 7; $i++) {
					$output .= "\t\t  <td>&nbsp;</td>\n";
				}
				$output .= "\t\t </tr>\n";
			}

			#--- determine next and previous month and year
			$prev_month_txt = $this->get_month($m, -1);
			$next_month_txt = $this->get_month($m, 1);

			if(($m - 1) < 1) {
				$prev_month = 12;
				$prev_year = $y - 1;
			} else {
				$prev_month = $m - 1;
				$prev_year = $y;
			}
			if(($m + 1) > 12) {
				$next_month = 1;
				$next_year = $y + 1;
			} else {
				$next_month = $m + 1;
				$next_year = $y;
			}

			$prev_month = sprintf("%02d", $prev_month);
			$next_month = sprintf("%02d", $next_month);

			$base_url = BASE_URL;
			$output .= <<<CAL_NAV
			 <tr>
			  <th colspan="3" align="left"><a href="$base_url?m=$prev_month&amp;y=$prev_year">&lt; $prev_month_txt</a></th>
			  <td>&nbsp;</td>
			  <th colspan="3" align="right"><a href="$base_url?m=$next_month&amp;y=$next_year">$next_month_txt &gt;</a></th>
			 </tr>
			</table>
CAL_NAV;

			return $output;
		}

		/*== get previous/current/next month abreviation ==*/
		function get_month($month, $pos = 0) {

			//--- get a timestamp from the middle of the month (but not from <= 1970!)
			$timestamp = mktime(12, 0, 0, 1, 15, 1980);
			$month_offset = 2592000; // 30 days

			//--- Remove leading zero if present
			$month = trim(sprintf('%2d', $month));
			$month--;

			if ($pos == -1 || $pos == 1) {
				$month += $pos;
			}
			$timestamp += $month * $month_offset;

			return strftime('%h', $timestamp);
		}

		/*== get the last day of the month ==*/
		function get_last_month_day($mon,$year)
		{
		    for ($tday=28; $tday <= 31; $tday++)  {
	        $tdate = getdate(mktime(0,0,0,$mon,$tday,$year));
	        if ($tdate["mon"] != $mon) { break; }

		    }
		    $tday--;

		    return $tday;
		}

		//-----------------------------------------------
		//--- METHOD: checkLogin
		//--- PURPOSE: verify login
		//--- PARAMETERS: username
		//--- 				password
		//--- RETURNS: TRUE/FALSE
		//-----------------------------------------------
		function checkLogin($user, $passwd)
		{
			$query = "SELECT
							id,
							email,
							post_by,
							post_entry,
							post_comment,
							admin
						 FROM
					 		{$this->prefix}users
					 	 WHERE
							user='$user'
						 AND
							password=MD5(MD5('$passwd'))";

			//--- Issue Query
			if ($this->dbObj->query($query) && $this->dbObj->getResultCnt() > 0) {
				//--- Retrieve Results
				$row = $this->dbObj->getRow();
				$_SESSION['login'] = TRUE;
				$_SESSION['post_by'] = $row['post_by'];
				$_SESSION['uid'] = $row['id'];
				$_SESSION['post_entry'] = ((int) $row['post_entry'] == 1) ? TRUE : FALSE;
				$_SESSION['post_comment'] = ((int) $row['post_comment'] == 1) ? TRUE : FALSE;
				$_SESSION['admin'] = ((int) $row['admin'] == 1) ? TRUE : FALSE;
				$stat = TRUE;
 			} else {
				//--- Query Error
				echo $this->dbObj->getError();
				$_SESSION['login'] = FALSE;
				$stat = FALSE;
			}

			return TRUE;
		}

	} //end of class
?>